import { Injectable, NgModule, Component, ViewChild, Input, Output } from '@angular/core';
import { CustomFieldsModule, ControlErrorsModule, EmptyStateModule, DynamicFormModule, ButtonModule, LoadingStateModule, FieldType, FormField, LocaleModule } from '@seniorsistemas/angular-components';
import { PermissionsModule } from '@seniorsistemas/platform-components';
import { HttpParams, HttpClient } from '@angular/common/http';
import { MessageService } from 'primeng/components/common/messageservice';
import { TranslateService, TranslateModule } from '@ngx-translate/core';
import { throwError, Subject, forkJoin, of } from 'rxjs';
import { catchError, takeUntil, filter, map, tap } from 'rxjs/operators';
import { CommonModule } from '@angular/common';
import { FormsModule, ReactiveFormsModule, Validators, FormControl, FormGroup, FormBuilder } from '@angular/forms';
import { HotkeyModule, Hotkey, HotkeysService } from 'angular2-hotkeys';
import { CurrencyMaskModule } from 'ng2-currency-mask';
import { CalendarModule } from 'primeng/calendar';
import { ConfirmDialogModule } from 'primeng/confirmdialog';
import { InputTextModule } from 'primeng/inputtext';
import { MessagesModule } from 'primeng/messages';
import { PanelModule } from 'primeng/panel';
import { SharedModule } from 'primeng/shared';
import { SplitButtonModule } from 'primeng/splitbutton';
import { __awaiter } from 'tslib';
import { user } from '@seniorsistemas/senior-platform-data';
import { Router, ActivatedRoute } from '@angular/router';
import * as moment_ from 'moment';
import { ConfirmationService } from 'primeng/api';

/**
 * @fileoverview added by tsickle
 * Generated from: shared/services/entity-service.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/**
 * @template T
 */
class EntityService {
    /**
     * @param {?} http
     * @param {?} messageService
     * @param {?} entityUrl
     * @param {?} actionsUrl
     * @param {?} translate
     */
    constructor(http, messageService, entityUrl, actionsUrl, translate) {
        this.http = http;
        this.messageService = messageService;
        this.entityUrl = entityUrl;
        this.actionsUrl = actionsUrl;
        this.translate = translate;
        this.http = http;
        this.messageService = messageService;
        this.entityUrl = entityUrl;
        this.actionsUrl = actionsUrl;
        this.translate = translate;
        this.defaultCatch = this.defaultCatch.bind(this);
    }
    /**
     * @param {?} listParams
     * @return {?}
     */
    getListQueryParams(listParams) {
        const { page = 0, size = 10, sort = [], filterQuery = "", displayFields = [] } = listParams;
        /** @type {?} */
        let params = new HttpParams();
        params = params.append("size", String(size));
        params = params.append("offset", String(page));
        if (sort && sort.length) {
            params = params.append("orderby", sort
                .map((/**
             * @param {?} s
             * @return {?}
             */
            s => {
                /** @type {?} */
                let order = "";
                if (s.order === 1)
                    order = " asc";
                else if (s.order === -1)
                    order = " desc";
                return `${s.field}${order}`;
            }))
                .join(", "));
        }
        if (filterQuery)
            params = params.append("filter", filterQuery);
        if (displayFields && displayFields.length)
            params = params.append("displayfields", displayFields.join());
        return params;
    }
    /**
     * @private
     * @param {?} listParams
     * @return {?}
     */
    getBodyParams(listParams) {
        const { page = 0, size = 10, sort = [], filterQuery = "", displayFields = [] } = listParams;
        /** @type {?} */
        const bodyParams = {};
        bodyParams.size = size;
        bodyParams.offset = page;
        if (sort && sort.length) {
            bodyParams.orderBy = sort
                .map((/**
             * @param {?} s
             * @return {?}
             */
            s => {
                /** @type {?} */
                let order = "";
                if (s.order === 1)
                    order = " asc";
                else if (s.order === -1)
                    order = " desc";
                return `${s.field}${order}`;
            }))
                .join(", ");
        }
        if (filterQuery)
            bodyParams.filter = filterQuery;
        if (displayFields && displayFields.length)
            bodyParams.displayfields = displayFields.join();
        return bodyParams;
    }
    /**
     * @return {?}
     */
    defaultCatch() {
        return catchError((/**
         * @param {?} err
         * @return {?}
         */
        (err) => {
            if (err) {
                /** @type {?} */
                let summary = err.status ? String(err.status) : "Error";
                /** @type {?} */
                let detail = (err.error && err.error.message) || err.statusText || err.message || "Error";
                if (err.status === 401) {
                    summary = this.translate.instant("hcm_clocking_event_foundation.general.error_unauthorized_title");
                    detail = this.translate.instant("hcm_clocking_event_foundation.general.error_unauthorized_description");
                }
                this.messageService.add({
                    severity: "error",
                    summary,
                    detail,
                });
            }
            return throwError(err);
        }));
    }
    /**
     * @param {?} listParams
     * @return {?}
     */
    list(listParams) {
        return this.http.get(this.entityUrl, { params: this.getListQueryParams(listParams) }).pipe(this.defaultCatch());
    }
    /**
     * @param {?} id
     * @return {?}
     */
    get(id) {
        return this.http.get(`${this.entityUrl}/${id}`).pipe(this.defaultCatch());
    }
    /**
     * @param {?} entity
     * @return {?}
     */
    insert(entity) {
        return this.http.post(`${this.entityUrl}`, entity).pipe(this.defaultCatch());
    }
    /**
     * @param {?} id
     * @param {?} entity
     * @return {?}
     */
    update(id, entity) {
        return this.http.put(`${this.entityUrl}/${id}`, entity).pipe(this.defaultCatch());
    }
    /**
     * @param {?} id
     * @return {?}
     */
    delete(id) {
        return this.http.delete(`${this.entityUrl}/${id}`).pipe(this.defaultCatch());
    }
    /**
     * @param {?} listParams
     * @param {?} action
     * @return {?}
     */
    listCustomFilter(listParams, action) {
        return this.http.post(`${this.actionsUrl}/${action}`, this.getBodyParams(listParams)).pipe(this.defaultCatch());
    }
}
if (false) {
    /**
     * @type {?}
     * @protected
     */
    EntityService.prototype.http;
    /**
     * @type {?}
     * @protected
     */
    EntityService.prototype.messageService;
    /**
     * @type {?}
     * @protected
     */
    EntityService.prototype.entityUrl;
    /**
     * @type {?}
     * @protected
     */
    EntityService.prototype.actionsUrl;
    /**
     * @type {?}
     * @protected
     */
    EntityService.prototype.translate;
}
/**
 * @record
 */
function ListParams() { }
if (false) {
    /** @type {?|undefined} */
    ListParams.prototype.page;
    /** @type {?|undefined} */
    ListParams.prototype.size;
    /** @type {?|undefined} */
    ListParams.prototype.sort;
    /** @type {?|undefined} */
    ListParams.prototype.filterQuery;
    /** @type {?|undefined} */
    ListParams.prototype.displayFields;
}
/**
 * @record
 */
function BodyParams() { }
if (false) {
    /** @type {?|undefined} */
    BodyParams.prototype.offset;
    /** @type {?|undefined} */
    BodyParams.prototype.size;
    /** @type {?|undefined} */
    BodyParams.prototype.orderBy;
    /** @type {?|undefined} */
    BodyParams.prototype.filter;
    /** @type {?|undefined} */
    BodyParams.prototype.displayfields;
}

/**
 * @fileoverview added by tsickle
 * Generated from: core/entities/bridge/bridge.service.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class BridgeService extends EntityService {
    /**
     * @param {?} http
     * @param {?} messageService
     * @param {?} translate
     */
    constructor(http, messageService, translate) {
        super(http, messageService, `hcm_clocking_event_foundation/general/entities/bridge`, `hcm_clocking_event_foundation/general/actions`, translate);
        this.http = http;
        this.messageService = messageService;
        this.translate = translate;
    }
}
BridgeService.decorators = [
    { type: Injectable }
];
/** @nocollapse */
BridgeService.ctorParameters = () => [
    { type: HttpClient },
    { type: MessageService },
    { type: TranslateService }
];
if (false) {
    /**
     * @type {?}
     * @protected
     */
    BridgeService.prototype.http;
    /**
     * @type {?}
     * @protected
     */
    BridgeService.prototype.messageService;
    /**
     * @type {?}
     * @protected
     */
    BridgeService.prototype.translate;
}

/**
 * @fileoverview added by tsickle
 * Generated from: core/entities/bridge/bridge.module.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class BridgeModule {
}
BridgeModule.decorators = [
    { type: NgModule, args: [{
                imports: [
                    PermissionsModule.forChild([
                        {
                            name: "bridge",
                            actions: ["Visualizar", "Incluir", "Editar", "Excluir"],
                            uri: `res://senior.com.br/hcm_clocking_event_foundation/general/entities/bridge`,
                        },
                    ]),
                ],
                providers: [
                    BridgeService
                ]
            },] }
];

/**
 * @fileoverview added by tsickle
 * Generated from: core/entities/company-clocking-event-indications/company-clocking-event-indications.service.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class CompanyClockingEventIndicationsService extends EntityService {
    /**
     * @param {?} http
     * @param {?} messageService
     * @param {?} translate
     */
    constructor(http, messageService, translate) {
        super(http, messageService, `hcm_clocking_event_foundation/general/entities/companyClockingEventIndications`, `hcm_clocking_event_foundation/general/actions`, translate);
        this.http = http;
        this.messageService = messageService;
        this.translate = translate;
    }
}
CompanyClockingEventIndicationsService.decorators = [
    { type: Injectable }
];
/** @nocollapse */
CompanyClockingEventIndicationsService.ctorParameters = () => [
    { type: HttpClient },
    { type: MessageService },
    { type: TranslateService }
];
if (false) {
    /**
     * @type {?}
     * @protected
     */
    CompanyClockingEventIndicationsService.prototype.http;
    /**
     * @type {?}
     * @protected
     */
    CompanyClockingEventIndicationsService.prototype.messageService;
    /**
     * @type {?}
     * @protected
     */
    CompanyClockingEventIndicationsService.prototype.translate;
}

/**
 * @fileoverview added by tsickle
 * Generated from: core/entities/company-clocking-event-indications/company-clocking-event-indications.module.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/*{CA:PROJECT_IMPORTS:START}*/
/*{CA:PROJECT_IMPORTS:END}*/
class CompanyClockingEventIndicationsModule {
}
CompanyClockingEventIndicationsModule.decorators = [
    { type: NgModule, args: [{
                imports: [
                    PermissionsModule.forChild([
                        {
                            name: "companyClockingEventIndications",
                            actions: ["Visualizar", "Incluir", "Editar", "Excluir"],
                            uri: `res://senior.com.br/hcm_clocking_event_foundation/general/entities/companyClockingEventIndications`,
                        },
                    ]),
                ],
                providers: [
                    CompanyClockingEventIndicationsService,
                ],
                declarations: [
                /*{CA:MODULE_DECLARATIONS:START}*/
                /*{CA:MODULE_DECLARATIONS:END}*/
                ],
                exports: [
                /*{CA:MODULE_EXPORTS:START}*/
                /*{CA:MODULE_EXPORTS:END}*/
                ],
            },] }
];

/**
 * @fileoverview added by tsickle
 * Generated from: core/entities/e-001-pes/e-001-pes.service.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class E001PesService extends EntityService {
    /**
     * @param {?} http
     * @param {?} messageService
     * @param {?} translate
     */
    constructor(http, messageService, translate) {
        super(http, messageService, `hcm_clocking_event_foundation/general/entities/e001pes`, `hcm_clocking_event_foundation/general/actions`, translate);
        this.http = http;
        this.messageService = messageService;
        this.translate = translate;
    }
    /**
     * @param {?} listParams
     * @return {?}
     */
    listExternalE001Pes(listParams) {
        return this.http
            .get("erpx_fnd/pessoa/entities/e001pes", {
            params: this.getListQueryParams(listParams),
        })
            .pipe(this.defaultCatch());
    }
}
E001PesService.decorators = [
    { type: Injectable }
];
/** @nocollapse */
E001PesService.ctorParameters = () => [
    { type: HttpClient },
    { type: MessageService },
    { type: TranslateService }
];
if (false) {
    /**
     * @type {?}
     * @protected
     */
    E001PesService.prototype.http;
    /**
     * @type {?}
     * @protected
     */
    E001PesService.prototype.messageService;
    /**
     * @type {?}
     * @protected
     */
    E001PesService.prototype.translate;
}

/**
 * @fileoverview added by tsickle
 * Generated from: core/entities/e-001-pes/e-001-pes.module.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/*{CA:PROJECT_IMPORTS:START}*/
/*{CA:PROJECT_IMPORTS:END}*/
class E001PesModule {
}
E001PesModule.decorators = [
    { type: NgModule, args: [{
                imports: [
                    PermissionsModule.forChild([
                        {
                            name: "e001pes",
                            actions: ["Visualizar", "Incluir", "Editar", "Excluir"],
                            uri: `res://senior.com.br/erpx_fnd/pessoa/entities/e001pes`,
                        },
                    ]),
                ],
                providers: [
                    E001PesService,
                ],
                declarations: [
                /*{CA:MODULE_DECLARATIONS:START}*/
                /*{CA:MODULE_DECLARATIONS:END}*/
                ],
                exports: [
                /*{CA:MODULE_EXPORTS:START}*/
                /*{CA:MODULE_EXPORTS:END}*/
                ],
            },] }
];

/**
 * @fileoverview added by tsickle
 * Generated from: core/entities/employee/employee.service.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class EmployeeService extends EntityService {
    /**
     * @param {?} http
     * @param {?} messageService
     * @param {?} translate
     */
    constructor(http, messageService, translate) {
        super(http, messageService, `hcm_contract/employment_contract/entities/employee`, `hcm_contract/employment_contract/actions`, translate);
        this.http = http;
        this.messageService = messageService;
        this.translate = translate;
    }
    /**
     * @param {?} listParams
     * @return {?}
     */
    listExternalEmployee(listParams) {
        return this.http
            .get("hcm_contract/employment_contract/entities/employee", {
            params: this.getListQueryParams(listParams),
        })
            .pipe(this.defaultCatch());
    }
}
EmployeeService.decorators = [
    { type: Injectable }
];
/** @nocollapse */
EmployeeService.ctorParameters = () => [
    { type: HttpClient },
    { type: MessageService },
    { type: TranslateService }
];
if (false) {
    /**
     * @type {?}
     * @protected
     */
    EmployeeService.prototype.http;
    /**
     * @type {?}
     * @protected
     */
    EmployeeService.prototype.messageService;
    /**
     * @type {?}
     * @protected
     */
    EmployeeService.prototype.translate;
}

/**
 * @fileoverview added by tsickle
 * Generated from: core/entities/employee/employee.module.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/*{CA:PROJECT_IMPORTS:START}*/
/*{CA:PROJECT_IMPORTS:END}*/
class EmployeeModule {
}
EmployeeModule.decorators = [
    { type: NgModule, args: [{
                imports: [
                    PermissionsModule.forChild([
                        {
                            name: "employee",
                            actions: ["Visualizar", "Incluir", "Editar", "Excluir"],
                            uri: `res://senior.com.br/hcm_contract/employment_contract/entities/employee`,
                        },
                    ]),
                ],
                providers: [
                    EmployeeService,
                ],
                declarations: [
                /*{CA:MODULE_DECLARATIONS:START}*/
                /*{CA:MODULE_DECLARATIONS:END}*/
                ],
                exports: [
                /*{CA:MODULE_EXPORTS:START}*/
                /*{CA:MODULE_EXPORTS:END}*/
                ],
            },] }
];

/**
 * @fileoverview added by tsickle
 * Generated from: core/entities/situation-clocking-event/situation-clocking-event.service.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/*{CA:PROJECT_IMPORTS:START}*/
/*{CA:PROJECT_IMPORTS:END}*/
class SituationClockingEventService extends EntityService {
    /*{CA:CLASS_ATTRIBUTES:START}*/
    /*{CA:CLASS_ATTRIBUTES:END}*/
    /**
     * @param {?} http
     * @param {?} messageService
     * @param {?} translate
     */
    constructor(http, messageService, translate) {
        super(http, messageService, `hcm_clocking_event_foundation/general/entities/situationClockingEvent`, `hcm_clocking_event_foundation/general/actions`, translate);
        this.http = http;
        this.messageService = messageService;
        this.translate = translate;
        /*{CA:CONSTRUCTOR_END:START}*/
        /*{CA:CONSTRUCTOR_END:END}*/
    }
}
SituationClockingEventService.decorators = [
    { type: Injectable }
];
/** @nocollapse */
SituationClockingEventService.ctorParameters = () => [
    { type: HttpClient },
    { type: MessageService },
    { type: TranslateService }
];
if (false) {
    /**
     * @type {?}
     * @protected
     */
    SituationClockingEventService.prototype.http;
    /**
     * @type {?}
     * @protected
     */
    SituationClockingEventService.prototype.messageService;
    /**
     * @type {?}
     * @protected
     */
    SituationClockingEventService.prototype.translate;
}

/**
 * @fileoverview added by tsickle
 * Generated from: core/entities/situation-clocking-event/situation-clocking-event.module.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/*{CA:PROJECT_IMPORTS:START}*/
/*{CA:PROJECT_IMPORTS:END}*/
class SituationClockingEventModule {
}
SituationClockingEventModule.decorators = [
    { type: NgModule, args: [{
                imports: [
                    PermissionsModule.forChild([
                        {
                            name: "situationClockingEvent",
                            actions: ["Visualizar", "Incluir", "Editar", "Excluir"],
                            uri: `res://senior.com.br/hcm_clocking_event_foundation/general/entities/situationClockingEvent`,
                        },
                    ]),
                ],
                providers: [
                    SituationClockingEventService,
                ],
                declarations: [
                /*{CA:MODULE_DECLARATIONS:START}*/
                /*{CA:MODULE_DECLARATIONS:END}*/
                ],
                exports: [
                /*{CA:MODULE_EXPORTS:START}*/
                /*{CA:MODULE_EXPORTS:END}*/
                ],
            },] }
];

/**
 * @fileoverview added by tsickle
 * Generated from: core/entities/situation/situation.service.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/*{CA:PROJECT_IMPORTS:START}*/
/*{CA:PROJECT_IMPORTS:END}*/
class SituationService extends EntityService {
    /*{CA:CLASS_ATTRIBUTES:START}*/
    /*{CA:CLASS_ATTRIBUTES:END}*/
    /**
     * @param {?} http
     * @param {?} messageService
     * @param {?} translate
     */
    constructor(http, messageService, translate) {
        super(http, messageService, `hcm_clocking_event_foundation/general/entities/situation`, `hcm_clocking_event_foundation/general/actions`, translate);
        this.http = http;
        this.messageService = messageService;
        this.translate = translate;
        /*{CA:CONSTRUCTOR_END:START}*/
        /*{CA:CONSTRUCTOR_END:END}*/
    }
    /**
     * @param {?} listParams
     * @return {?}
     */
    listExternalSituation(listParams) {
        return this.http
            .get("hcm_foundation/general/entities/situation", {
            params: this.getListQueryParams(listParams),
        })
            .pipe(this.defaultCatch());
    }
}
SituationService.decorators = [
    { type: Injectable }
];
/** @nocollapse */
SituationService.ctorParameters = () => [
    { type: HttpClient },
    { type: MessageService },
    { type: TranslateService }
];
if (false) {
    /**
     * @type {?}
     * @protected
     */
    SituationService.prototype.http;
    /**
     * @type {?}
     * @protected
     */
    SituationService.prototype.messageService;
    /**
     * @type {?}
     * @protected
     */
    SituationService.prototype.translate;
}

/**
 * @fileoverview added by tsickle
 * Generated from: core/entities/situation/situation.module.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/*{CA:PROJECT_IMPORTS:START}*/
/*{CA:PROJECT_IMPORTS:END}*/
class SituationModule {
}
SituationModule.decorators = [
    { type: NgModule, args: [{
                imports: [
                    PermissionsModule.forChild([
                        {
                            name: "situation",
                            actions: ["Visualizar", "Incluir", "Editar", "Excluir"],
                            uri: `res://senior.com.br/hcm_foundation/general/entities/situation`,
                        },
                    ]),
                ],
                providers: [
                    SituationService,
                ],
                declarations: [
                /*{CA:MODULE_DECLARATIONS:START}*/
                /*{CA:MODULE_DECLARATIONS:END}*/
                ],
                exports: [
                /*{CA:MODULE_EXPORTS:START}*/
                /*{CA:MODULE_EXPORTS:END}*/
                ],
            },] }
];

/**
 * @fileoverview added by tsickle
 * Generated from: core/entities/time-evaluation-definition/time-evaluation-definition.service.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/*{CA:PROJECT_IMPORTS:START}*/
/*{CA:PROJECT_IMPORTS:END}*/
class TimeEvaluationDefinitionService extends EntityService {
    /*{CA:CLASS_ATTRIBUTES:START}*/
    /*{CA:CLASS_ATTRIBUTES:END}*/
    /**
     * @param {?} http
     * @param {?} messageService
     * @param {?} translate
     */
    constructor(http, messageService, translate) {
        super(http, messageService, `hcm_clocking_event_foundation/general/entities/timeEvaluationDefinition`, `hcm_clocking_event_foundation/general/actions`, translate);
        this.http = http;
        this.messageService = messageService;
        this.translate = translate;
        /*{CA:CONSTRUCTOR_END:START}*/
        /*{CA:CONSTRUCTOR_END:END}*/
    }
}
TimeEvaluationDefinitionService.decorators = [
    { type: Injectable }
];
/** @nocollapse */
TimeEvaluationDefinitionService.ctorParameters = () => [
    { type: HttpClient },
    { type: MessageService },
    { type: TranslateService }
];
if (false) {
    /**
     * @type {?}
     * @protected
     */
    TimeEvaluationDefinitionService.prototype.http;
    /**
     * @type {?}
     * @protected
     */
    TimeEvaluationDefinitionService.prototype.messageService;
    /**
     * @type {?}
     * @protected
     */
    TimeEvaluationDefinitionService.prototype.translate;
}

/**
 * @fileoverview added by tsickle
 * Generated from: core/entities/time-evaluation-definition/time-evaluation-definition.module.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/*{CA:PROJECT_IMPORTS:START}*/
/*{CA:PROJECT_IMPORTS:END}*/
class TimeEvaluationDefinitionModule {
}
TimeEvaluationDefinitionModule.decorators = [
    { type: NgModule, args: [{
                imports: [
                    PermissionsModule.forChild([
                        {
                            name: "timeEvaluationDefinition",
                            actions: ["Visualizar", "Incluir", "Editar", "Excluir"],
                            uri: `res://senior.com.br/hcm_clocking_event_foundation/general/entities/timeEvaluationDefinition`,
                        },
                    ]),
                ],
                providers: [
                    TimeEvaluationDefinitionService,
                ],
                declarations: [
                /*{CA:MODULE_DECLARATIONS:START}*/
                /*{CA:MODULE_DECLARATIONS:END}*/
                ],
                exports: [
                /*{CA:MODULE_EXPORTS:START}*/
                /*{CA:MODULE_EXPORTS:END}*/
                ],
            },] }
];

/**
 * @fileoverview added by tsickle
 * Generated from: core/entities/time-evaluation-situation-definition-history/time-evaluation-situation-definition-history.service.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/*{CA:PROJECT_IMPORTS:START}*/
/*{CA:PROJECT_IMPORTS:END}*/
class TimeEvaluationSituationDefinitionHistoryService extends EntityService {
    /*{CA:CLASS_ATTRIBUTES:START}*/
    /*{CA:CLASS_ATTRIBUTES:END}*/
    /**
     * @param {?} http
     * @param {?} messageService
     * @param {?} translate
     */
    constructor(http, messageService, translate) {
        super(http, messageService, `$hcm_clocking_event_foundation/general/entities/timeEvaluationSituationDefinitionHistory`, `$hcm_clocking_event_foundation/general/actions`, translate);
        this.http = http;
        this.messageService = messageService;
        this.translate = translate;
        /*{CA:CONSTRUCTOR_END:START}*/
        /*{CA:CONSTRUCTOR_END:END}*/
    }
}
TimeEvaluationSituationDefinitionHistoryService.decorators = [
    { type: Injectable }
];
/** @nocollapse */
TimeEvaluationSituationDefinitionHistoryService.ctorParameters = () => [
    { type: HttpClient },
    { type: MessageService },
    { type: TranslateService }
];
if (false) {
    /**
     * @type {?}
     * @protected
     */
    TimeEvaluationSituationDefinitionHistoryService.prototype.http;
    /**
     * @type {?}
     * @protected
     */
    TimeEvaluationSituationDefinitionHistoryService.prototype.messageService;
    /**
     * @type {?}
     * @protected
     */
    TimeEvaluationSituationDefinitionHistoryService.prototype.translate;
}

/**
 * @fileoverview added by tsickle
 * Generated from: core/entities/time-evaluation-situation-definition-history/time-evaluation-situation-definition-history.module.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/*{CA:PROJECT_IMPORTS:START}*/
/*{CA:PROJECT_IMPORTS:END}*/
class TimeEvaluationSituationDefinitionHistoryModule {
}
TimeEvaluationSituationDefinitionHistoryModule.decorators = [
    { type: NgModule, args: [{
                imports: [
                    PermissionsModule.forChild([
                        {
                            name: "timeEvaluationSituationDefinitionHistory",
                            actions: ["Visualizar", "Incluir", "Editar", "Excluir"],
                            uri: `res://senior.com.br/hcm_clocking_event_foundation/general/entities/timeEvaluationSituationDefinitionHistory`,
                        },
                    ]),
                ],
                providers: [
                    TimeEvaluationSituationDefinitionHistoryService,
                ],
                declarations: [
                /*{CA:MODULE_DECLARATIONS:START}*/
                /*{CA:MODULE_DECLARATIONS:END}*/
                ],
                exports: [
                /*{CA:MODULE_EXPORTS:START}*/
                /*{CA:MODULE_EXPORTS:END}*/
                ],
            },] }
];

/**
 * @fileoverview added by tsickle
 * Generated from: core/entities/time-evaluation-situation-definition/time-evaluation-situation-definition.service.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/*{CA:PROJECT_IMPORTS:START}*/
/*{CA:PROJECT_IMPORTS:END}*/
class TimeEvaluationSituationDefinitionService extends EntityService {
    /*{CA:CLASS_ATTRIBUTES:START}*/
    /*{CA:CLASS_ATTRIBUTES:END}*/
    /**
     * @param {?} http
     * @param {?} messageService
     * @param {?} translate
     */
    constructor(http, messageService, translate) {
        super(http, messageService, `hcm_clocking_event_foundation/general/entities/timeEvaluationSituationDefinition`, `hcm_clocking_event_foundation/general/actions`, translate);
        this.http = http;
        this.messageService = messageService;
        this.translate = translate;
        /*{CA:CONSTRUCTOR_END:START}*/
        /*{CA:CONSTRUCTOR_END:END}*/
    }
    /**
     * @param {?} timeEvaluationSituationDefinitionId
     * @param {?} id
     * @return {?}
     */
    getTimeEvaluationSituationDefinitionHistory(timeEvaluationSituationDefinitionId, id) {
        return this.http
            .get(`hcm_clocking_event_foundation/general/entities/timeEvaluationSituationDefinitionHistory/${id}`)
            .pipe(this.defaultCatch());
    }
    /**
     * @param {?} timeEvaluationSituationDefinitionId
     * @param {?} id
     * @param {?} timeEvaluationSituationDefinitionHistoryDto
     * @return {?}
     */
    updateTimeEvaluationSituationDefinitionHistory(timeEvaluationSituationDefinitionId, id, timeEvaluationSituationDefinitionHistoryDto) {
        return this.http
            .put(`hcm_clocking_event_foundation/general/entities/timeEvaluationSituationDefinitionHistory/${id}`, timeEvaluationSituationDefinitionHistoryDto)
            .pipe(this.defaultCatch());
    }
    /**
     * @param {?} timeEvaluationSituationDefinitionId
     * @param {?} listParams
     * @return {?}
     */
    listTimeEvaluationSituationDefinitionHistory(timeEvaluationSituationDefinitionId, listParams) {
        return this.http
            .get(`hcm_clocking_event_foundation/general/entities/timeEvaluationSituationDefinitionHistory`, { params: this.getListQueryParams(listParams) })
            .pipe(this.defaultCatch());
    }
    /**
     * @param {?} timeEvaluationSituationDefinitionId
     * @param {?} timeEvaluationSituationDefinitionHistoryDto
     * @return {?}
     */
    insertTimeEvaluationSituationDefinitionHistory(timeEvaluationSituationDefinitionId, timeEvaluationSituationDefinitionHistoryDto) {
        return this.http
            .post(`hcm_clocking_event_foundation/general/entities/timeEvaluationSituationDefinitionHistory`, timeEvaluationSituationDefinitionHistoryDto)
            .pipe(this.defaultCatch());
    }
    /**
     * @param {?} timeEvaluationSituationDefinitionId
     * @param {?} id
     * @return {?}
     */
    deleteTimeEvaluationSituationDefinitionHistory(timeEvaluationSituationDefinitionId, id) {
        return this.http
            .delete(`hcm_clocking_event_foundation/general/entities/timeEvaluationSituationDefinitionHistory/${id}`)
            .pipe(this.defaultCatch());
    }
}
TimeEvaluationSituationDefinitionService.decorators = [
    { type: Injectable }
];
/** @nocollapse */
TimeEvaluationSituationDefinitionService.ctorParameters = () => [
    { type: HttpClient },
    { type: MessageService },
    { type: TranslateService }
];
if (false) {
    /**
     * @type {?}
     * @protected
     */
    TimeEvaluationSituationDefinitionService.prototype.http;
    /**
     * @type {?}
     * @protected
     */
    TimeEvaluationSituationDefinitionService.prototype.messageService;
    /**
     * @type {?}
     * @protected
     */
    TimeEvaluationSituationDefinitionService.prototype.translate;
}

/**
 * @fileoverview added by tsickle
 * Generated from: core/entities/time-evaluation-situation-definition/time-evaluation-situation-definition.module.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/*{CA:PROJECT_IMPORTS:START}*/
/*{CA:PROJECT_IMPORTS:END}*/
class TimeEvaluationSituationDefinitionModule {
}
TimeEvaluationSituationDefinitionModule.decorators = [
    { type: NgModule, args: [{
                imports: [
                    PermissionsModule.forChild([
                        {
                            name: "timeEvaluationSituationDefinition",
                            actions: ["Visualizar", "Incluir", "Editar", "Excluir"],
                            uri: `res://senior.com.br/hcm_clocking_event_foundation/general/entities/timeEvaluationSituationDefinition`,
                        },
                    ]),
                ],
                providers: [
                    TimeEvaluationSituationDefinitionService,
                ],
                declarations: [
                /*{CA:MODULE_DECLARATIONS:START}*/
                /*{CA:MODULE_DECLARATIONS:END}*/
                ],
                exports: [
                /*{CA:MODULE_EXPORTS:START}*/
                /*{CA:MODULE_EXPORTS:END}*/
                ],
            },] }
];

/**
 * @fileoverview added by tsickle
 * Generated from: core/core-schedules.module.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class CoreSchedulesHistoriesModule {
}
CoreSchedulesHistoriesModule.decorators = [
    { type: NgModule, args: [{
                imports: [
                    BridgeModule,
                    EmployeeModule,
                    E001PesModule,
                    CompanyClockingEventIndicationsModule,
                    TimeEvaluationDefinitionModule,
                    SituationModule,
                    TimeEvaluationSituationDefinitionModule,
                    TimeEvaluationSituationDefinitionHistoryModule,
                    SituationClockingEventModule
                ]
            },] }
];

/**
 * @fileoverview added by tsickle
 * Generated from: shared/focus/focus.service.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class FocusService {
    /**
     * @return {?}
     */
    focusFirstInvalidInput() {
        /** @type {?} */
        const invalidFields = Array.from(document.getElementsByClassName("ng-invalid"));
        /** @type {?} */
        const firstField = invalidFields.find((/**
         * @param {?} f
         * @return {?}
         */
        (f) => f.nodeName !== "FORM"));
        if (firstField.nodeName === "P-CALENDAR") {
            /** @type {?} */
            const firstInputId = firstField.getAttribute("ng-reflect-input-id");
            /** @type {?} */
            const firstInvalidInput = document.getElementById(firstInputId);
            if (firstInvalidInput)
                firstInvalidInput.focus();
        }
        else if (firstField.nodeName === "S-LOOKUP") {
            /** @type {?} */
            const nestedInput = this.getNestedInput(firstField.firstElementChild);
            if (nestedInput)
                nestedInput.focus();
        }
        else
            firstField.focus();
    }
    /**
     * @private
     * @param {?} element
     * @return {?}
     */
    getNestedInput(element) {
        if (element.nodeName === "INPUT") {
            return element;
        }
        return this.getNestedInput(element.firstElementChild);
    }
}

/**
 * @fileoverview added by tsickle
 * Generated from: shared/services/field-customization.service.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class FieldCustomizationService {
    /**
     * @param {?} http
     * @param {?} messageService
     */
    constructor(http, messageService) {
        this.http = http;
        this.messageService = messageService;
        this.http = http;
        this.messageService = messageService;
        this.defaultCatch = this.defaultCatch.bind(this);
    }
    /**
     * @param {?} objects
     * @return {?}
     */
    commitFiles(objects) {
        return this.http.post("platform/field_customization/actions/commitObject", { objects }).pipe(this.defaultCatch());
    }
    /**
     * @param {?} objects
     * @return {?}
     */
    deleteFiles(objects) {
        return this.http.post("platform/field_customization/actions/deleteObjects", objects).pipe(this.defaultCatch());
    }
    /**
     * @param {?} formGroup
     * @return {?}
     */
    getFiles(formGroup) {
        /** @type {?} */
        let fieldCustomization = [];
        if (formGroup.value.custom) {
            fieldCustomization = formGroup.value.custom.fieldCustomization || [];
            delete formGroup.value.custom.fieldCustomization;
        }
        /** @type {?} */
        const filesToCommit = [];
        /** @type {?} */
        let filesToDelete = {};
        fieldCustomization.forEach((/**
         * @param {?} __0
         * @return {?}
         */
        ({ domain, service, entity, toDelete, toInsert }) => {
            if (!this.isEmpty(toInsert)) {
                /** @type {?} */
                const files = Object.keys(toInsert).map((/**
                 * @param {?} key
                 * @return {?}
                 */
                (key) => {
                    /** @type {?} */
                    const version = toInsert[key].version;
                    /** @type {?} */
                    const fileName = toInsert[key].name;
                    /** @type {?} */
                    const objectId = toInsert[key].objectId;
                    return { version, fileName, objectId };
                }));
                if (!this.isEmpty(files)) {
                    filesToCommit.push(...files);
                }
            }
            if (!this.isEmpty(toDelete)) {
                /** @type {?} */
                const objects = [];
                Object.keys(toDelete).forEach((/**
                 * @param {?} key
                 * @return {?}
                 */
                (key) => {
                    /** @type {?} */
                    const fields = toDelete[key] || [];
                    /** @type {?} */
                    const files = fields.map((/**
                     * @param {?} file
                     * @return {?}
                     */
                    (file) => {
                        return {
                            field: key,
                            objectId: file,
                        };
                    }));
                    objects.push(...files);
                }));
                filesToDelete = { domain, service, entityName: entity, objects };
            }
        }));
        return { filesToCommit, filesToDelete };
    }
    /**
     * @param {?} object
     * @return {?}
     */
    isEmpty(object) {
        if (Array.isArray(object)) {
            return object.length === 0;
        }
        return Object.entries(object).length === 0 && object.constructor === Object;
    }
    /**
     * @return {?}
     */
    defaultCatch() {
        return catchError((/**
         * @param {?} err
         * @return {?}
         */
        (err) => {
            if (err) {
                /** @type {?} */
                const summary = err.status ? String(err.status) : "Error";
                /** @type {?} */
                const detail = (err.error && err.error.message) || err.statusText || err.message || "Error";
                this.messageService.add({
                    severity: "error",
                    summary,
                    detail,
                });
            }
            return throwError(err);
        }));
    }
}
FieldCustomizationService.decorators = [
    { type: Injectable }
];
/** @nocollapse */
FieldCustomizationService.ctorParameters = () => [
    { type: HttpClient },
    { type: MessageService }
];
if (false) {
    /**
     * @type {?}
     * @protected
     */
    FieldCustomizationService.prototype.http;
    /**
     * @type {?}
     * @protected
     */
    FieldCustomizationService.prototype.messageService;
}

/**
 * @fileoverview added by tsickle
 * Generated from: shared/storage/storage.service.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class StorageService {
    constructor() {
        this.GET_USER_ID = user.getUserData().then((/**
         * @param {?} user
         * @return {?}
         */
        user => user.id));
    }
    /**
     * @param {?} key
     * @param {?} value
     * @return {?}
     */
    store(key, value) {
        return __awaiter(this, void 0, void 0, function* () {
            localStorage.setItem(`${yield this.GET_USER_ID}_${key}`, JSON.stringify(value));
        });
    }
    /**
     * @param {?} key
     * @return {?}
     */
    get(key) {
        return __awaiter(this, void 0, void 0, function* () {
            return JSON.parse(localStorage.getItem(`${yield this.GET_USER_ID}_${key}`)) || {};
        });
    }
}
if (false) {
    /**
     * @type {?}
     * @private
     */
    StorageService.prototype.GET_USER_ID;
}

/**
 * @fileoverview added by tsickle
 * Generated from: shared/storage/filters-storage.service.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class FiltersStorageService extends StorageService {
    constructor() {
        super(...arguments);
        this.FILTERS_KEY = "SENIOR_FILTERS";
    }
    /**
     * @param {?} key
     * @param {?} filters
     * @return {?}
     */
    storeFilters(key, filters) {
        const _super = Object.create(null, {
            get: { get: () => super.get },
            store: { get: () => super.store }
        });
        return __awaiter(this, void 0, void 0, function* () {
            /** @type {?} */
            const store = (yield _super.get.call(this, this.FILTERS_KEY)) || {};
            this.removeEmptyValues(filters);
            store[key] = filters;
            yield _super.store.call(this, this.FILTERS_KEY, store);
        });
    }
    /**
     * @param {?} key
     * @return {?}
     */
    getFilters(key) {
        const _super = Object.create(null, {
            get: { get: () => super.get }
        });
        return __awaiter(this, void 0, void 0, function* () {
            /** @type {?} */
            const store = (yield _super.get.call(this, this.FILTERS_KEY)) || {};
            return store[key] || {};
        });
    }
    /**
     * @param {?} key
     * @return {?}
     */
    removeFilter(key) {
        const _super = Object.create(null, {
            get: { get: () => super.get },
            store: { get: () => super.store }
        });
        return __awaiter(this, void 0, void 0, function* () {
            /** @type {?} */
            const store = (yield _super.get.call(this, this.FILTERS_KEY)) || {};
            delete store[key];
            yield _super.store.call(this, this.FILTERS_KEY, store);
        });
    }
    /**
     * @param {?} key
     * @param {?} filters
     * @return {?}
     */
    clearFilterValue(key, filters) {
        const _super = Object.create(null, {
            get: { get: () => super.get },
            store: { get: () => super.store }
        });
        return __awaiter(this, void 0, void 0, function* () {
            /** @type {?} */
            const store = (yield _super.get.call(this, this.FILTERS_KEY)) || {};
            this.removeEmptyValues(filters);
            store[key] = filters;
            yield _super.store.call(this, this.FILTERS_KEY, store);
        });
    }
    /**
     * @private
     * @param {?} filters
     * @return {?}
     */
    removeEmptyValues(filters) {
        Object.keys(filters).forEach((/**
         * @param {?} field
         * @return {?}
         */
        (field) => {
            if (Array.isArray(filters[field]) ? filters[field].length === 0 : !filters[field]) {
                delete filters[field];
            }
        }));
    }
}
if (false) {
    /**
     * @type {?}
     * @private
     */
    FiltersStorageService.prototype.FILTERS_KEY;
}

/**
 * @fileoverview added by tsickle
 * Generated from: shared/storage/paginator-storage.service.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class PaginatorStorageService {
    constructor() {
        this.GET_USER_ID = user.getUserData().then((/**
         * @param {?} user
         * @return {?}
         */
        user => user.id));
        this.PAGINATOR_KEY = "SENIOR_PAGINATOR";
    }
    /**
     * @param {?} key
     * @param {?} value
     * @return {?}
     */
    store(key, value) {
        return __awaiter(this, void 0, void 0, function* () {
            sessionStorage.setItem(`${yield this.GET_USER_ID}_${key}`, JSON.stringify(value));
        });
    }
    /**
     * @param {?} key
     * @return {?}
     */
    get(key) {
        return __awaiter(this, void 0, void 0, function* () {
            return JSON.parse(sessionStorage.getItem(`${yield this.GET_USER_ID}_${key}`)) || {};
        });
    }
    /**
     * @param {?} key
     * @param {?=} listParams
     * @return {?}
     */
    storePaginator(key, listParams = {}) {
        return __awaiter(this, void 0, void 0, function* () {
            /** @type {?} */
            const store = (yield this.get(this.PAGINATOR_KEY)) || {};
            store[key] = listParams;
            yield this.store(this.PAGINATOR_KEY, store);
        });
    }
    /**
     * @param {?} key
     * @return {?}
     */
    getPaginator(key) {
        return __awaiter(this, void 0, void 0, function* () {
            /** @type {?} */
            const store = (yield this.get(this.PAGINATOR_KEY)) || {};
            return store[key] || {};
        });
    }
}
if (false) {
    /**
     * @type {?}
     * @private
     */
    PaginatorStorageService.prototype.GET_USER_ID;
    /**
     * @type {?}
     * @private
     */
    PaginatorStorageService.prototype.PAGINATOR_KEY;
}

/**
 * @fileoverview added by tsickle
 * Generated from: shared/shared-schedule.module.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/*{CA:PACKAGE_IMPORTS:END}*/
/*{CA:PROJECT_IMPORTS:START}*/
/*{CA:PROJECT_IMPORTS:END}*/
class SharedScheduleModule {
}
SharedScheduleModule.decorators = [
    { type: NgModule, args: [{
                imports: [
                    /*{CA:MODULE_IMPORTS:START}*/
                    SplitButtonModule,
                    MessagesModule,
                    FormsModule,
                    ReactiveFormsModule,
                    CommonModule,
                    CurrencyMaskModule,
                    TranslateModule,
                    CustomFieldsModule,
                    ControlErrorsModule,
                    EmptyStateModule,
                    DynamicFormModule,
                    PanelModule,
                    InputTextModule,
                    ButtonModule,
                    ConfirmDialogModule,
                    CalendarModule,
                    SharedModule,
                    HotkeyModule,
                    LoadingStateModule,
                ],
                providers: [
                    FiltersStorageService,
                    PaginatorStorageService,
                    FocusService,
                    FieldCustomizationService,
                ],
                declarations: [
                /*{CA:MODULE_DECLARATIONS:START}*/
                /*{CA:MODULE_DECLARATIONS:END}*/
                ],
                /*{CA:MODULE_CONFIG:START}*/
                exports: [
                    SplitButtonModule,
                    MessagesModule,
                    FormsModule,
                    ReactiveFormsModule,
                    CommonModule,
                    CurrencyMaskModule,
                    TranslateModule,
                    CustomFieldsModule,
                    ControlErrorsModule,
                    EmptyStateModule,
                    DynamicFormModule,
                    PanelModule,
                    InputTextModule,
                    ButtonModule,
                    ConfirmDialogModule,
                    CalendarModule,
                    SharedModule,
                    HotkeyModule,
                    LoadingStateModule
                ]
                /*{CA:MODULE_CONFIG:END}*/
            },] }
];

/**
 * @fileoverview added by tsickle
 * Generated from: core/entities/e-001-pes/e-001-pes.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/** @type {?} */
const moment = moment_;
// @HACK Necessary because of https://github.com/rollup/rollup/issues/670
class E001Pes {
    constructor() {
        this.excluido = false;
    }
    /**
     * @param {?} e001PesDto
     * @param {?=} originEntity
     * @return {?}
     */
    static fromDto(e001PesDto, originEntity) {
        /** @type {?} */
        const model = Object.assign({}, e001PesDto);
        model.createdDate = model.createdDate && moment(model.createdDate).toDate();
        model.lastModifiedDate = model.lastModifiedDate && moment(model.lastModifiedDate).toDate();
        /** @type {?} */
        const lookupSeparator = " - ";
        /** @type {?} */
        const displayFields = ["nomPes"];
        model.label = displayFields.map((/**
         * @param {?} field
         * @return {?}
         */
        field => model[field])).join(lookupSeparator);
        return (/** @type {?} */ (model));
    }
    /**
     * @param {?} e001Pes
     * @param {?=} originEntity
     * @return {?}
     */
    static toDto(e001Pes, originEntity) {
        /** @type {?} */
        const dto = Object.assign({}, e001Pes);
        dto.createdDate = dto.createdDate && moment(dto.createdDate).format();
        dto.lastModifiedDate = dto.lastModifiedDate && moment(dto.lastModifiedDate).format();
        delete dto.label;
        return dto;
    }
}
if (false) {
    /** @type {?} */
    E001Pes.prototype.id;
    /** @type {?} */
    E001Pes.prototype.nomPes;
    /** @type {?} */
    E001Pes.prototype.excluido;
    /** @type {?} */
    E001Pes.prototype.extIntSts;
    /** @type {?} */
    E001Pes.prototype.extIntMsg;
    /** @type {?} */
    E001Pes.prototype.createdBy;
    /** @type {?} */
    E001Pes.prototype.createdDate;
    /** @type {?} */
    E001Pes.prototype.lastModifiedBy;
    /** @type {?} */
    E001Pes.prototype.lastModifiedDate;
    /** @type {?} */
    E001Pes.prototype.custom;
}

/**
 * @fileoverview added by tsickle
 * Generated from: core/entities/employee/employee.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/** @type {?} */
const moment$1 = moment_;
// @HACK Necessary because of https://github.com/rollup/rollup/issues/670
class Employee {
    constructor() {
        this.deleted = false;
    }
    /**
     * @param {?} employeeDto
     * @param {?=} originEntity
     * @return {?}
     */
    static fromDto(employeeDto, originEntity) {
        /** @type {?} */
        const model = Object.assign({}, employeeDto);
        model.hireDate = model.hireDate && moment$1(model.hireDate).toDate();
        model.dismissalDate = model.dismissalDate && moment$1(model.dismissalDate).toDate();
        model.createdDate = model.createdDate && moment$1(model.createdDate).toDate();
        model.lastModifiedDate = model.lastModifiedDate && moment$1(model.lastModifiedDate).toDate();
        /** @type {?} */
        const lookupSeparator = " - ";
        /** @type {?} */
        const displayFields = [
            "id",
            "code",
            "person.nomPes",
            "hireDate",
            "dismissalDate",
            "deleted",
            "extIntSts",
            "extIntMsg",
            "createdBy",
            "createdDate",
            "lastModifiedBy",
            "lastModifiedDate",
        ];
        model.label = displayFields.map((/**
         * @param {?} field
         * @return {?}
         */
        field => model[field])).join(lookupSeparator);
        if (originEntity !== "E001Pes" && model.person)
            model.person = E001Pes.fromDto(model.person, "Employee");
        return (/** @type {?} */ (model));
    }
    /**
     * @param {?} employee
     * @param {?=} originEntity
     * @return {?}
     */
    static toDto(employee, originEntity) {
        /** @type {?} */
        const dto = Object.assign({}, employee);
        dto.hireDate = dto.hireDate && moment$1(dto.hireDate).format("YYYY-MM-DD");
        dto.dismissalDate = dto.dismissalDate && moment$1(dto.dismissalDate).format("YYYY-MM-DD");
        dto.createdDate = dto.createdDate && moment$1(dto.createdDate).format();
        dto.lastModifiedDate = dto.lastModifiedDate && moment$1(dto.lastModifiedDate).format();
        delete dto.label;
        if (originEntity !== "E001Pes" && dto.person)
            dto.person = E001Pes.toDto(dto.person, "Employee");
        return dto;
    }
}
if (false) {
    /** @type {?} */
    Employee.prototype.id;
    /** @type {?} */
    Employee.prototype.code;
    /** @type {?} */
    Employee.prototype.person;
    /** @type {?} */
    Employee.prototype.employer;
    /** @type {?} */
    Employee.prototype.hireDate;
    /** @type {?} */
    Employee.prototype.dismissalDate;
    /** @type {?} */
    Employee.prototype.deleted;
    /** @type {?} */
    Employee.prototype.extIntSts;
    /** @type {?} */
    Employee.prototype.extIntMsg;
    /** @type {?} */
    Employee.prototype.createdBy;
    /** @type {?} */
    Employee.prototype.createdDate;
    /** @type {?} */
    Employee.prototype.lastModifiedBy;
    /** @type {?} */
    Employee.prototype.lastModifiedDate;
    /** @type {?} */
    Employee.prototype.custom;
}

/**
 * @fileoverview added by tsickle
 * Generated from: core/entities/bridge/bridge.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/** @type {?} */
const moment$2 = moment_;
// @HACK Necessary because of https://github.com/rollup/rollup/issues/670
class Bridge {
    /**
     * @param {?} bridgeDto
     * @param {?=} originEntity
     * @return {?}
     */
    static fromDto(bridgeDto, originEntity) {
        /** @type {?} */
        const model = Object.assign({}, bridgeDto);
        model.originDate = model.originDate && moment$2(model.originDate).toDate();
        model.destinationDate = model.destinationDate && moment$2(model.destinationDate).toDate();
        model.createdDate = model.createdDate && moment$2(model.createdDate).toDate();
        model.lastModifiedDate = model.lastModifiedDate && moment$2(model.lastModifiedDate).toDate();
        /** @type {?} */
        const lookupSeparator = " - ";
        /** @type {?} */
        const displayFields = [
            "id",
            "employee.code",
            "employee.person.nomPes",
            "originDate",
            "destinationDate",
            "createdBy",
            "createdDate",
            "lastModifiedBy",
            "lastModifiedDate",
        ];
        model.label = displayFields.map((/**
         * @param {?} field
         * @return {?}
         */
        field => model[field])).join(lookupSeparator);
        if (originEntity !== "Employee" && model.employee)
            model.employee = Employee.fromDto(model.employee, "Bridge");
        return (/** @type {?} */ (model));
    }
    /**
     * @param {?} bridge
     * @param {?=} originEntity
     * @return {?}
     */
    static toDto(bridge, originEntity) {
        /** @type {?} */
        const dto = Object.assign({}, bridge);
        dto.originDate = dto.originDate && moment$2(dto.originDate).format("YYYY-MM-DD");
        dto.destinationDate = dto.destinationDate && moment$2(dto.destinationDate).format("YYYY-MM-DD");
        dto.createdDate = dto.createdDate && moment$2(dto.createdDate).format();
        dto.lastModifiedDate = dto.lastModifiedDate && moment$2(dto.lastModifiedDate).format();
        delete dto.label;
        if (originEntity !== "Employee" && dto.employee)
            dto.employee = Employee.toDto(dto.employee, "Bridge");
        return dto;
    }
}
if (false) {
    /** @type {?} */
    Bridge.prototype.id;
    /** @type {?} */
    Bridge.prototype.employee;
    /** @type {?} */
    Bridge.prototype.originDate;
    /** @type {?} */
    Bridge.prototype.destinationDate;
    /** @type {?} */
    Bridge.prototype.createdBy;
    /** @type {?} */
    Bridge.prototype.createdDate;
    /** @type {?} */
    Bridge.prototype.lastModifiedBy;
    /** @type {?} */
    Bridge.prototype.lastModifiedDate;
    /** @type {?} */
    Bridge.prototype.custom;
}

/**
 * @fileoverview added by tsickle
 * Generated from: shared/utils/date-validator.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/** @type {?} */
const moment$3 = moment_;
// @HACK Necessary because of https://github.com/rollup/rollup/issues/670
/**
 * @param {?} startDateTime
 * @param {?} endDateTime
 * @return {?}
 */
function startDateTimeIsBeforeEndDateTimeValidator(startDateTime, endDateTime) {
    if (startDateTime && endDateTime && startDateTime.value && endDateTime.value) {
        /** @type {?} */
        const isInvalid = moment$3(startDateTime.value).seconds(0).isSameOrAfter(moment$3(endDateTime.value).seconds(0)) ? { startDateTimeIsBeforeEndDateTime: { value: [endDateTime.value, startDateTime.value] } } : null;
        if (isInvalid) {
            startDateTime.markAsDirty();
            endDateTime.markAsDirty();
            endDateTime.setErrors(isInvalid);
            startDateTime.setErrors(isInvalid);
            return isInvalid;
        }
        removeErrorFromField(endDateTime, 'startDateTimeIsBeforeEndDateTime');
        removeErrorFromField(startDateTime, 'startDateTimeIsBeforeEndDateTime');
    }
    else if (startDateTime && startDateTime.value && !(endDateTime && endDateTime.value)) {
        removeErrorFromField(startDateTime, 'startDateTimeIsBeforeEndDateTime');
    }
    else if (!(startDateTime && startDateTime.value) && endDateTime && endDateTime.value) {
        removeErrorFromField(endDateTime, 'startDateTimeIsBeforeEndDateTime');
    }
    return null;
}
;
/**
 * @param {?} startDate
 * @param {?} endDate
 * @return {?}
 */
function startDateIsBeforeOrEqualToEndDateValidator(startDate, endDate) {
    if (startDate && endDate && startDate.value && endDate.value) {
        /** @type {?} */
        const forbidden = startDate.value > endDate.value ? { startDateIsBeforeEndDate: { value: endDate.value } } : null;
        if (forbidden) {
            startDate.markAsDirty();
            endDate.markAsDirty();
            startDate.setErrors(forbidden);
            endDate.setErrors(forbidden);
            return forbidden;
        }
        removeErrorFromField(endDate, 'startDateIsBeforeEndDate');
        removeErrorFromField(startDate, 'startDateIsBeforeEndDate');
    }
    else if (startDate && startDate.value && !(endDate && endDate.value)) {
        removeErrorFromField(startDate, 'startDateIsBeforeEndDate');
    }
    else if (!(startDate && startDate.value) && endDate && endDate.value) {
        removeErrorFromField(endDate, 'startDateIsBeforeEndDate');
    }
    return null;
}
/**
 * @param {?} field
 * @param {?} error
 * @return {?}
 */
function removeErrorFromField(field, error) {
    if (field.errors) {
        delete field.errors[error];
    }
    if (JSON.stringify(field.errors) == JSON.stringify({})) {
        field.setErrors(null);
    }
}
/**
 * @param {?} startDate
 * @param {?} endDate
 * @return {?}
 */
function startDateIsBeforeEndDateValidator(startDate, endDate) {
    if (startDate && endDate && startDate.value && endDate.value) {
        /** @type {?} */
        const forbidden = moment$3(startDate.value).isSameOrAfter(endDate.value) ? { startDateIsBeforeEndDate: { value: endDate.value } } : null;
        if (forbidden) {
            startDate.markAsDirty();
            endDate.markAsDirty();
            startDate.setErrors(forbidden);
            endDate.setErrors(forbidden);
            return forbidden;
        }
        removeErrorFromField(endDate, 'startDateIsBeforeEndDate');
        removeErrorFromField(startDate, 'startDateIsBeforeEndDate');
    }
    else if (startDate && startDate.value && !(endDate && endDate.value)) {
        removeErrorFromField(startDate, 'startDateIsBeforeEndDate');
    }
    else if (!(startDate && startDate.value) && endDate && endDate.value) {
        removeErrorFromField(endDate, 'startDateIsBeforeEndDate');
    }
    return null;
}

/**
 * @fileoverview added by tsickle
 * Generated from: shared/utils/utils.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/** @type {?} */
const numberTypes = [FieldType.Integer, FieldType.Double];
/** @type {?} */
const numberPattern = /^\d+\b$/;
/** @type {?} */
const mergeUnique = (/**
 * @param {?} array
 * @param {?} otherArray
 * @return {?}
 */
(array, otherArray) => array.concat(otherArray.filter((/**
 * @param {?} item
 * @return {?}
 */
item => !array.includes(item)))));
/** @type {?} */
const isValidFilter = (/**
 * @param {?} type
 * @param {?} value
 * @return {?}
 */
(type, value) => {
    const { isValidValue, typeExists } = getTypeInformation(type, value);
    return !(typeExists && !isValidValue);
});
/** @type {?} */
const getTypeInformation = (/**
 * @param {?} type
 * @param {?} value
 * @return {?}
 */
(type, value) => {
    switch (type) {
        case FieldType.Time:
        case FieldType.Date:
        case FieldType.DateTime:
            return { isValidValue: false, typeExists: true };
        case FieldType.Integer:
        case FieldType.Double:
            return {
                isValidValue: value.match(numberPattern),
                typeExists: numberTypes.includes(type),
            };
        default:
            return {
                isValidValue: value.match(numberPattern),
                typeExists: numberTypes.includes(type),
            };
    }
});
/** @type {?} */
const convertMinutesToTime = (/**
 * @param {?} minutes
 * @param {?=} monthMinute
 * @return {?}
 */
(minutes, monthMinute) => {
    /** @type {?} */
    let time = minutes.replace('.', '');
    /** @type {?} */
    let hour = Math.floor(parseInt(time) / 60);
    /** @type {?} */
    let minute = parseInt(time) % 60;
    /** @type {?} */
    let msg = (hour < 10) ? '0' + hour : hour;
    msg += ':';
    msg += (minute < 10) ? '0' + minute : '' + minute;
    if (monthMinute) {
        msg = putZeroAtHours(msg.toString());
    }
    return msg;
});
/** @type {?} */
const putZeroAtHours = (/**
 * @param {?} msg
 * @return {?}
 */
(msg) => {
    if (msg.length === 4) {
        return '00' + msg;
    }
    else if (msg.length === 5) {
        return '0' + msg;
    }
    else {
        return msg;
    }
});
const ɵ0 = putZeroAtHours;
/** @type {?} */
const convertTimeToMinutes = (/**
 * @param {?} time
 * @return {?}
 */
(time) => {
    if (time) {
        /** @type {?} */
        const array = time.toString().split(':');
        return (array[0] * 60) + parseInt(array[1]);
    }
    return null;
});

/**
 * @fileoverview added by tsickle
 * Generated from: lib/bridge/form/bridge-form.component.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/** @type {?} */
const moment$4 = moment_;
// @HACK Necessary because of https://github.com/rollup/rollup/issues/670
class BridgeFormComponent {
    /**
     * @param {?} companyClockingEventIndicationsService
     * @param {?} bridgeService
     * @param {?} router
     * @param {?} route
     * @param {?} messageService
     * @param {?} confirmationService
     * @param {?} formBuilder
     * @param {?} translate
     * @param {?} hotkeysService
     * @param {?} fieldCustomization
     * @param {?} focusService
     * @param {?} employeeService
     */
    constructor(companyClockingEventIndicationsService, bridgeService, router, route, messageService, confirmationService, formBuilder, translate, hotkeysService, fieldCustomization, focusService, employeeService) {
        this.companyClockingEventIndicationsService = companyClockingEventIndicationsService;
        this.bridgeService = bridgeService;
        this.router = router;
        this.route = route;
        this.messageService = messageService;
        this.confirmationService = confirmationService;
        this.formBuilder = formBuilder;
        this.translate = translate;
        this.hotkeysService = hotkeysService;
        this.fieldCustomization = fieldCustomization;
        this.focusService = focusService;
        this.employeeService = employeeService;
        this.localeConfig = {};
        this.currencyLocaleOptions = {};
        this.permissions = {};
        this.allPermissions = {};
        this.mainPanelCollapsed = false;
        this.contractTypeOptions = [
            {
                label: this.translate.instant("hcm_clocking_event_foundation.general.contract_type_employee"),
                value: "EMPLOYEE",
            },
            {
                label: this.translate.instant("hcm_clocking_event_foundation.general.contract_type_director"),
                value: "DIRECTOR",
            },
            {
                label: this.translate.instant("hcm_clocking_event_foundation.general.contract_type_trainee"),
                value: "TRAINEE",
            },
            {
                label: this.translate.instant("hcm_clocking_event_foundation.general.contract_type_aprentice"),
                value: "APRENTICE",
            },
            {
                label: this.translate.instant("hcm_clocking_event_foundation.general.contract_type_third_party"),
                value: "THIRD_PARTY",
            },
        ];
        this.employeeLookupDisplayFields = [
            "employer.codEmp",
            "code",
            "person.nomPes",
            "employmentRelationship.contractType",
        ];
        this.employeeAdvancedDisplayFields = ["employer.codEmp", "code", "person.nomPes", "employmentRelationship.contractType"];
        this.employeeLookupSeparator = " - ";
        /*{CA:CLASS_ATTRIBUTES:START}*/
        this.cacheLimitDaysBackwardScheduling = new Map();
        this.onClose = new Subject();
        this.onCloseObservable = this.onClose.asObservable();
        this.ngUnsubscribe = new Subject();
        /*{CA:CONSTRUCTOR_END:START}*/
        /*{CA:CONSTRUCTOR_END:END}*/
    }
    /**
     * @return {?}
     */
    ngOnInit() {
        /*{CA:ON_INIT_START:START}*/
        /*{CA:ON_INIT_START:END}*/
        this.formGroup = this.getFormGroup();
        if (this.lockedEmployee) {
            this.loadLockedEmployee(this.lockedEmployee);
            this.onSubmitObservable.pipe(takeUntil(this.ngUnsubscribe), filter((/**
             * @param {?} name
             * @return {?}
             */
            name => name === 'bridge'))).subscribe((/**
             * @return {?}
             */
            () => this.onSave()));
            if (this.onLockedEmployeeChanges) {
                this.onLockedEmployeeChanges
                    .pipe(takeUntil(this.ngUnsubscribe)).subscribe((/**
                 * @param {?} value
                 * @return {?}
                 */
                (value) => {
                    this.formGroup = this.getFormGroup();
                    this.loadLockedEmployee(value);
                }));
            }
        }
        else {
            this.setHotkeys();
        }
        this.route.params
            .pipe(takeUntil(this.ngUnsubscribe))
            .subscribe((/**
         * @param {?} params
         * @return {?}
         */
        (params) => this.onRouteParamsChange(params)));
        this.route.data
            .pipe(takeUntil(this.ngUnsubscribe))
            .subscribe((/**
         * @param {?} data
         * @return {?}
         */
        (data) => this.onRouteDataChange(data)));
        this.employeeSearchFields = this.getEmployeeSearchFields();
        this.employeeSearchGridFields = this.getEmployeeSearchGridFields();
        /*{CA:ON_INIT_END:START}*/
        /*{CA:ON_INIT_END:END}*/
    }
    /**
     * @private
     * @param {?} value
     * @return {?}
     */
    loadLockedEmployee(value) {
        if (!this.formGroup.value.employee) {
            this.loading = true;
            this.employeeService.listExternalEmployee({
                filterQuery: `id eq '${value.employeeId}'`,
                displayFields: this.employeeLookupDisplayFields
            }).subscribe((/**
             * @param {?} dto
             * @return {?}
             */
            (dto) => {
                /** @type {?} */
                const bridge = new Bridge();
                bridge.originDate = moment$4(value.evaluationDate).toDate();
                bridge.employee = Employee.fromDto(dto.contents[0], "Bridge");
                this.updateSuggestions(bridge);
                this.formGroup.patchValue(bridge);
                this.formGroup.controls['employee'].disable();
                this.loading = false;
            }));
        }
        else {
            this.formGroup.controls['bridge'].setValue(value.evaluationDate);
        }
    }
    /**
     * @return {?}
     */
    ngAfterViewInit() {
        /*{CA:ON_VIEW_INIT_START:START}*/
        /*{CA:ON_VIEW_INIT_START:END}*/
        /*{CA:ON_VIEW_INIT_END:START}*/
        /*{CA:ON_VIEW_INIT_END:END}*/
    }
    /**
     * @return {?}
     */
    ngOnDestroy() {
        /*{CA:ON_DESTROY_START:START}*/
        /*{CA:ON_DESTROY_START:END}*/
        this.ngUnsubscribe.unsubscribe();
        this.cacheLimitDaysBackwardScheduling.clear();
        /*{CA:ON_DESTROY_END:START}*/
        /*{CA:ON_DESTROY_END:END}*/
    }
    /**
     * @return {?}
     */
    setHotkeys() {
        /*{CA:SET_HOTKEYS_START:START}*/
        /*{CA:SET_HOTKEYS_START:END}*/
        this.hotkeysService.add(new Hotkey("alt+shift+x", (/**
         * @return {?}
         */
        () => {
            if (this.permissions.excluir)
                this.onDelete();
            return false;
        }), ["INPUT", "SELECT", "TEXTAREA"]));
        this.hotkeysService.add(new Hotkey("alt+shift+s", (/**
         * @return {?}
         */
        () => {
            if (this.isNew() || this.permissions.editar)
                this.onSave();
            return false;
        }), ["INPUT", "SELECT", "TEXTAREA"]));
        this.hotkeysService.add(new Hotkey("alt+shift+c", (/**
         * @return {?}
         */
        () => {
            this.onCancel();
            return false;
        }), ["INPUT", "SELECT", "TEXTAREA"]));
        /*{CA:SET_HOTKEYS_END:START}*/
        /*{CA:SET_HOTKEYS_END:END}*/
    }
    /**
     * @return {?}
     */
    isNew() {
        return this.routeParams.bridge == "new";
    }
    /**
     * @param {?} params
     * @return {?}
     */
    onRouteParamsChange(params) {
        /*{CA:ON_ROUTE_PARAMS_CHANGE_START:START}*/
        /*{CA:ON_ROUTE_PARAMS_CHANGE_START:END}*/
        this.routeParams = params;
        /*{CA:ON_ROUTE_PARAMS_CHANGE_END:START}*/
        /*{CA:ON_ROUTE_PARAMS_CHANGE_END:END}*/
    }
    /**
     * @param {?} value
     * @return {?}
     */
    updateSuggestions(value) {
        /*{CA:ON_UPDATE_SUGGESTIONS_START:START}*/
        /*{CA:ON_UPDATE_SUGGESTIONS_START:END}*/
        if (value.employee) {
            value.employee.employmentRelationship.contractTypeLabel = this.loadLabelFromEnum(value.employee.employmentRelationship.contractType);
            value.employee.label = this.getSuggestionValue([
                "employer.codEmp",
                "code",
                "person.nomPes",
                "employmentRelationship.contractTypeLabel",
            ], "employee", value, this.employeeLookupSeparator);
            if (value.employee.label.trim() === this.employeeLookupSeparator.trim()) {
                delete value.employee.label;
            }
        }
        /*{CA:ON_UPDATE_SUGGESTIONS_END:START}*/
        /*{CA:ON_UPDATE_SUGGESTIONS_END:END}*/
    }
    /**
     * @param {?} displayFields
     * @param {?} ownerEntity
     * @param {?} value
     * @param {?} separator
     * @return {?}
     */
    getSuggestionValue(displayFields, ownerEntity, value, separator) {
        return displayFields
            .map((/**
         * @param {?} field
         * @return {?}
         */
        (field) => this.getProp(value, `${ownerEntity}.${field}`)))
            .reduce((/**
         * @param {?} acc
         * @param {?} val
         * @return {?}
         */
        (acc, val) => `${acc}${separator}${val}`));
    }
    /**
     * @param {?} data
     * @return {?}
     */
    onRouteDataChange(data) {
        /*{CA:ON_ROUTE_DATA_CHANGE_START:START}*/
        /*{CA:ON_ROUTE_DATA_CHANGE_START:END}*/
        const { currencySymbol, thousandsSeparator, decimalSeparator } = data.localeConfig.number;
        this.localeConfig = data.localeConfig;
        this.currencyLocaleOptions = {
            align: "left",
            prefix: currencySymbol,
            thousands: thousandsSeparator,
            decimal: decimalSeparator,
        };
        this.permissions = data.allPermissions.bridge;
        this.allPermissions = data.allPermissions;
        this.validateVisualization();
        if (this.lockedEmployee) {
            return;
        }
        else if (data.entity && data.entity[0]) {
            /** @type {?} */
            const canEdit = this.permissions.editar;
            if (!canEdit)
                this.formGroup.disable();
            /** @type {?} */
            const value = Bridge.fromDto(data.entity[0]);
            this.updateSuggestions(value);
            this.formGroup.patchValue(value);
            /** @type {?} */
            let limitDate = new Date();
            limitDate.setDate(limitDate.getDate() -
                data.entity[1].timeEvaluationDefinition.limitDaysBackwardScheduling);
            this.cacheLimitDaysBackwardScheduling.set(data.entity[1].company.id, limitDate);
        }
        else {
            this.formGroup.patchValue(new Bridge());
        }
        /*{CA:ON_ROUTE_DATA_CHANGE_END:START}*/
        /*{CA:ON_ROUTE_DATA_CHANGE_END:END}*/
    }
    /**
     * @return {?}
     */
    onCancel() {
        /*{CA:ON_CANCEL_START:START}*/
        /*{CA:ON_CANCEL_START:END}*/
        this.goBack();
        /*{CA:ON_CANCEL_END:START}*/
        /*{CA:ON_CANCEL_END:END}*/
    }
    /**
     * @param {?} filesToDelete
     * @param {?} filesToCommit
     * @return {?}
     */
    onSendFile(filesToDelete, filesToCommit) {
        /*{CA:ON_SEND_FILE:START}*/
        /*{CA:ON_SEND_FILE:END}*/
        /*{CA:ON_SEND_FILE:START}*/
        /*{CA:ON_SEND_FILE:END}*/
        /** @type {?} */
        const observables = [];
        if (!this.fieldCustomization.isEmpty(filesToDelete)) {
            observables.push(this.fieldCustomization.deleteFiles(filesToDelete));
        }
        if (!this.fieldCustomization.isEmpty(filesToCommit)) {
            observables.push(this.fieldCustomization.commitFiles(filesToCommit));
        }
        if (!this.fieldCustomization.isEmpty(observables)) {
            return forkJoin(observables);
        }
        else {
            return of({});
        }
    }
    /**
     * @return {?}
     */
    onSave() {
        /*{CA:ON_SAVE_START:START}*/
        /*{CA:ON_SAVE_START:END}*/
        this.loading = true;
        if (!this.formGroup.valid) {
            this.loading = false;
            return this.validateAllFormFields(this.formGroup);
        }
        const { filesToDelete, filesToCommit } = this.fieldCustomization.getFiles(this.formGroup);
        this.getSaveObservable()
            .pipe(takeUntil(this.ngUnsubscribe), catchError((/**
         * @param {?} err
         * @return {?}
         */
        (err) => {
            this.loading = false;
            return throwError(err);
        })))
            .subscribe((/**
         * @return {?}
         */
        () => {
            /*{CA:ON_SAVE_START_TOP:START}*/
            /*{CA:ON_SAVE_START_TOP:END}*/
            this.onSendFile(filesToDelete, filesToCommit)
                .pipe(takeUntil(this.ngUnsubscribe), catchError((/**
             * @param {?} err
             * @return {?}
             */
            (err) => {
                /*{CA:ON_SEND_ERROR_TOP:START}*/
                /*{CA:ON_SEND_ERROR_BOTTOM:END}*/
                this.loading = false;
                /*{CA:ON_SEND_ERROR_TOP:START}*/
                /*{CA:ON_SEND_ERROR_BOTTOM:END}*/
                return throwError(err);
            })))
                .subscribe((/**
             * @return {?}
             */
            () => {
                this.addMessage("success", "hcm_clocking_event_foundation.general.saved_message_title", "hcm_clocking_event_foundation.general.saved_message_content");
                if (this.lockedEmployee) {
                    this.onClose.next(true);
                    this.loading = false;
                }
                else {
                    this.goBack();
                }
                /*{CA:ON_SAVE_START_BOTTOM:START}*/
                /*{CA:ON_SAVE_START_BOTTOM:END}*/
            }));
        }));
        /*{CA:ON_SAVE_END:START}*/
        /*{CA:ON_SAVE_END:END}*/
    }
    /**
     * @return {?}
     */
    onDelete() {
        /*{CA:ON_DELETE_START:START}*/
        /*{CA:ON_DELETE_START:END}*/
        this.confirmationService.confirm({
            message: this.translate.instant("hcm_clocking_event_foundation.general.delete_confirmation_message"),
            header: this.translate.instant("hcm_clocking_event_foundation.general.delete_confirmation_title"),
            accept: (/**
             * @return {?}
             */
            () => this.getDeleteObservable().pipe(takeUntil(this.ngUnsubscribe)).subscribe()),
        });
        /*{CA:ON_DELETE_END:START}*/
        /*{CA:ON_DELETE_END:END}*/
    }
    /**
     * @param {?} obj
     * @param {?} path
     * @return {?}
     */
    getProp(obj, path) {
        return path
            .split(".")
            .reduce((/**
         * @param {?} result
         * @param {?} prop
         * @return {?}
         */
        (result, prop) => (result[prop] === undefined ? "" : result[prop])), obj);
    }
    /**
     * @private
     * @param {?} value
     * @return {?}
     */
    loadLabelFromEnum(value) {
        return this.contractTypeOptions.filter((/**
         * @param {?} r
         * @return {?}
         */
        (r) => r.value === value))[0].label;
    }
    /**
     * @private
     * @param {?} value
     * @return {?}
     */
    loadEnumFromLabel(value) {
        value = value.toUpperCase().trim();
        if (value && value !== undefined) {
            return this.contractTypeOptions
                .filter((/**
             * @param {?} r
             * @return {?}
             */
            (r) => {
                /** @type {?} */
                const match = r.label.toUpperCase().match(value);
                return match !== null && match.length !== 0;
            }))
                .map((/**
             * @param {?} r
             * @return {?}
             */
            (r) => r.value));
        }
        return [];
    }
    /**
     * @param {?} value
     * @return {?}
     */
    onEmployeeLookupRequest(value) {
        /*{CA:ON_EMPLOYEE_LOOKUP_REQUEST_START:START}*/
        /*{CA:ON_EMPLOYEE_LOOKUP_REQUEST_START:END}*/
        /** @type {?} */
        const sort = this.employeeLookupDisplayFields.map((/**
         * @param {?} field
         * @return {?}
         */
        (field) => ({ field, order: 1 })));
        /** @type {?} */
        const filterQuery = this.getEmployeeSearchFields()
            .filter((/**
         * @param {?} __0
         * @return {?}
         */
        ({ type }) => isValidFilter(type, value)))
            .map((/**
         * @param {?} __0
         * @return {?}
         */
        ({ name, type }) => {
            if (typeof value == "number")
                return `${name} eq ${value}`;
            else if (type == FieldType.Date)
                return `${name} eq '${moment$4(value).format("YYYY-MM-DD")}'`;
            else if (type == FieldType.Time)
                return `${name} eq '${moment$4(value).format("HH:mm:ss")}'`;
            else if (type == FieldType.DateTime)
                return `${name} eq '${moment$4(value).format()}'`;
            else if (type == FieldType.Enum)
                return this.loadEnumFromLabel(value)
                    .map((/**
                 * @param {?} enumConstant
                 * @return {?}
                 */
                (enumConstant) => `${name} eq '${enumConstant}'`))
                    .join(" or ");
            else if (type == FieldType.String)
                return `containing(upper(${name}), upper('${value.replace(/'/g, "\\'")}'))`;
            else
                return `${name} eq '${value}'`;
        }))
            .filter((/**
         * @param {?} filter
         * @return {?}
         */
        (filter) => filter !== ""))
            .join(" or ");
        /** @type {?} */
        const displayFields = mergeUnique(this.employeeLookupDisplayFields, this.employeeAdvancedDisplayFields).concat("hireDate", "dismissalDate");
        this.employeeService
            .listExternalEmployee({ sort, filterQuery, displayFields })
            .pipe(takeUntil(this.ngUnsubscribe))
            .pipe(map((/**
         * @param {?} list
         * @return {?}
         */
        (list) => (Object.assign({}, list, { contents: list.contents.map((/**
             * @param {?} item
             * @return {?}
             */
            (item) => (Object.assign({}, item, { label: this.employeeLookupDisplayFields
                    .map((/**
                 * @param {?} field
                 * @return {?}
                 */
                (field) => {
                    if (field.indexOf(".") > 0)
                        item[field] = this.getProp(item, field);
                    if (field === "employmentRelationship.contractType") {
                        item[field] = this.loadLabelFromEnum(item[field]);
                    }
                    return item[field];
                }))
                    .join(this.employeeLookupSeparator) })))) })))))
            .subscribe((/**
         * @param {?} list
         * @return {?}
         */
        (list) => {
            this.employeeLookupSuggestions = list.contents;
        }));
        /*{CA:ON_EMPLOYEE_LOOKUP_REQUEST_END:START}*/
        /*{CA:ON_EMPLOYEE_LOOKUP_REQUEST_END:END}*/
    }
    /**
     * @param {?} event
     * @return {?}
     */
    onEmployeeSearchRequest(event) {
        /*{CA:ON_EMPLOYEE_SEARCH_REQUEST_START:START}*/
        /*{CA:ON_EMPLOYEE_SEARCH_REQUEST_START:END}*/
        /*{CA:ON_EMPLOYEE_SEARCH_REQUEST_START:START}*/
        /*{CA:ON_EMPLOYEE_SEARCH_REQUEST_START:END}*/
        const { first, rows, multiSortMeta, filterData } = event;
        /** @type {?} */
        const page = first / rows;
        /** @type {?} */
        const sort = multiSortMeta;
        /** @type {?} */
        const filterQuery = this.getEmployeeSearchFields()
            .filter((/**
         * @param {?} __0
         * @return {?}
         */
        ({ name }) => filterData[name] != undefined && filterData[name] != ""))
            .map((/**
         * @param {?} __0
         * @return {?}
         */
        ({ name, type }) => {
            /** @type {?} */
            const value = filterData[name];
            if (typeof value == "number")
                return `${name} eq ${value}`;
            else if (type == FieldType.Date)
                return `${name} eq '${moment$4(value).format("YYYY-MM-DD")}'`;
            else if (type == FieldType.Time)
                return `${name} eq '${moment$4(value).format("HH:mm:ss")}'`;
            else if (type == FieldType.DateTime)
                return `${name} eq '${moment$4(value).format()}'`;
            else if (type == FieldType.Enum)
                return `${name} eq '${value}'`;
            else if (type == FieldType.String)
                return `containing(upper(${name}), upper('${value.replace(/'/g, "\\'")}'))`;
            else
                return `${name} eq '${value}'`;
        }))
            .join(" and ");
        /** @type {?} */
        const displayFields = mergeUnique(this.employeeLookupDisplayFields, this.employeeAdvancedDisplayFields).concat("hireDate", "dismissalDate");
        this.employeeService
            .listExternalEmployee({ page, sort, filterQuery, displayFields })
            .pipe(takeUntil(this.ngUnsubscribe))
            .pipe(map((/**
         * @param {?} list
         * @return {?}
         */
        (list) => (Object.assign({}, list, { contents: list.contents.map((/**
             * @param {?} item
             * @return {?}
             */
            (item) => (Object.assign({}, item, { label: this.employeeLookupDisplayFields
                    .map((/**
                 * @param {?} field
                 * @return {?}
                 */
                (field) => {
                    if (field.indexOf(".") > 0)
                        item[field] = this.getProp(item, field); // NOSONAR
                    if (field === "employmentRelationship.contractType") { // NOSONAR
                        item[field] = this.loadLabelFromEnum(item[field]); // NOSONAR
                    } // NOSONAR
                    return item[field]; // NOSONAR
                })) // NOSONAR
                    .join(this.employeeLookupSeparator) })))) })))) // NOSONAR
        ) // NOSONAR
            .subscribe((/**
         * @param {?} list
         * @return {?}
         */
        (list) => {
            this.employeeSearchGridData = list.contents; // NOSONAR
            this.employeeSearchTotalRecords = list.totalElements; // NOSONAR
        })); // NOSONAR
        /*{CA:ON_EMPLOYEE_SEARCH_REQUEST_END:START}*/
        /*{CA:ON_EMPLOYEE_SEARCH_REQUEST_END:END}*/
    }
    /**
     * @private
     * @return {?}
     */
    getFormGroup() {
        /** @type {?} */
        const formGroup = this.formBuilder.group({
            id: [{ value: undefined, disabled: true }, Validators.compose([])],
            employee: [
                { value: undefined, disabled: false },
                Validators.compose([Validators.required]),
            ],
            originDate: [
                { value: undefined, disabled: false },
                Validators.compose([Validators.required]),
            ],
            destinationDate: [
                { value: undefined, disabled: false },
                Validators.compose([Validators.required]),
            ],
            createdBy: [{ value: undefined, disabled: true }, Validators.compose([])],
            createdDate: [{ value: undefined, disabled: true }, Validators.compose([])],
            lastModifiedBy: [{ value: undefined, disabled: true }, Validators.compose([])],
            lastModifiedDate: [{ value: undefined, disabled: true }, Validators.compose([])],
            custom: [],
        }, {
            validators: [
                this.validLimitDaysBackwardScheduling(),
                this.startDateIsBeforeEndDate(),
            ],
        });
        formGroup.controls.employee.valueChanges.subscribe((/**
         * @param {?} employee
         * @return {?}
         */
        (employee) => {
            if (employee) {
                /** @type {?} */
                let limitDaysBackwardScheduling = this.cacheLimitDaysBackwardScheduling.get(employee.employer.id);
                if (limitDaysBackwardScheduling === undefined) {
                    this.companyClockingEventIndicationsService
                        .get(employee.employer.id)
                        .pipe(catchError((/**
                     * @param {?} error
                     * @return {?}
                     */
                    (error) => {
                        formGroup.controls.employee.setErrors({
                            hasNotCompanyClockingEventIndications: { value: error },
                        });
                        return throwError(error);
                    })))
                        .subscribe((/**
                     * @param {?} companyClockingEventIndications
                     * @return {?}
                     */
                    (companyClockingEventIndications) => {
                        /** @type {?} */
                        let limitDate = new Date();
                        limitDate.setDate(limitDate.getDate() -
                            companyClockingEventIndications.timeEvaluationDefinition
                                .limitDaysBackwardScheduling);
                        this.cacheLimitDaysBackwardScheduling.set(companyClockingEventIndications.id, limitDate);
                    }));
                }
            }
        }));
        return formGroup;
    }
    /**
     * @private
     * @return {?}
     */
    getEmployeeSearchFields() {
        /** @type {?} */
        const searchFields = [
            new FormField({
                name: "employer.codEmp",
                label: this.translate.instant("hcm_clocking_event_foundation.general.employee_employer_cod_emp"),
                type: FieldType.Integer,
            }),
            new FormField({
                name: "code",
                label: this.translate.instant("hcm_clocking_event_foundation.general.employee_code"),
                type: FieldType.Integer,
            }),
            new FormField({
                name: "person.nomPes",
                label: this.translate.instant("hcm_clocking_event_foundation.general.employee_person_nom_pes"),
                type: FieldType.String,
            }),
            new FormField({
                name: "employmentRelationship.contractType",
                label: this.translate.instant("hcm_clocking_event_foundation.general.employee_employment_relationship_contract_type"),
                type: FieldType.Enum,
                options: this.contractTypeOptions,
            }),
        ];
        /*{CA:GET_EMPLOYEE_SEARCH_FIELDS:START}*/
        /*{CA:GET_EMPLOYEE_SEARCH_FIELDS:END}*/
        return searchFields;
    }
    /**
     * @private
     * @return {?}
     */
    getEmployeeSearchGridFields() {
        /** @type {?} */
        const searchGridFields = [
            new FormField({
                name: "employer.codEmp",
                label: this.translate.instant("hcm_clocking_event_foundation.general.employee_employer_cod_emp"),
                type: FieldType.Integer,
            }),
            new FormField({
                name: "code",
                label: this.translate.instant("hcm_clocking_event_foundation.general.employee_code"),
                type: FieldType.Integer,
            }),
            new FormField({
                name: "person.nomPes",
                label: this.translate.instant("hcm_clocking_event_foundation.general.employee_person_nom_pes"),
                type: FieldType.String,
            }),
            new FormField({
                name: "employmentRelationship.contractType",
                label: this.translate.instant("hcm_clocking_event_foundation.general.employee_employment_relationship_contract_type"),
                type: FieldType.Enum,
                options: this.contractTypeOptions
            }),
        ];
        /*{CA:GET_EMPLOYEE_SEARCH_GRID_FIELDS:START}*/
        /*{CA:GET_EMPLOYEE_SEARCH_GRID_FIELDS:END}*/
        return searchGridFields;
    }
    /**
     * @private
     * @return {?}
     */
    goBack() {
        /** @type {?} */
        const previousRoute = "../";
        this.router.navigate([previousRoute], { relativeTo: this.route.parent });
    }
    /**
     * @private
     * @param {?} formGroup
     * @return {?}
     */
    validateAllFormFields(formGroup) {
        Object.keys(formGroup.controls).forEach((/**
         * @param {?} field
         * @return {?}
         */
        (field) => {
            /** @type {?} */
            const control = formGroup.get(field);
            if (control instanceof FormControl)
                control.markAsDirty({ onlySelf: true });
            else if (control instanceof FormGroup)
                this.validateAllFormFields(control);
        }));
        this.focusService.focusFirstInvalidInput();
        /*{CA:FOCUS_FIRST_INVALID:START}*/
        /*{CA:FOCUS_FIRST_INVALID:END}*/
    }
    /**
     * @private
     * @return {?}
     */
    getSaveObservable() {
        this.formGroup.controls['employee'].enable();
        const { value } = this.formGroup;
        /** @type {?} */
        const bridgeDto = Bridge.toDto(value);
        /** @type {?} */
        let observable;
        if (this.isNew() || (this.lockedEmployee && !value.id)) {
            observable = this.bridgeService.insert(bridgeDto);
        }
        else {
            /** @type {?} */
            const id = this.routeParams.bridge;
            observable = this.bridgeService.update(id, bridgeDto);
        }
        return observable;
    }
    /**
     * @private
     * @return {?}
     */
    getDeleteObservable() {
        return this.bridgeService.delete(this.routeParams.bridge).pipe(tap((/**
         * @return {?}
         */
        () => {
            this.addMessage(// NOSONAR
            "success", // NOSONAR
            "hcm_clocking_event_foundation.general.deleted_message_title", // NOSONAR
            "hcm_clocking_event_foundation.general.deleted_message_content" // NOSONAR
            ); // NOSONAR
            this.goBack(); // NOSONAR
        })) // NOSONAR
        ); // NOSONAR
    } // NOSONAR
    // NOSONAR
    /**
     * @private
     * @return {?}
     */
    validateVisualization() {
        /*{CA:VALIDATE_VISUALIZATION_START:START}*/
        /*{CA:VALIDATE_VISUALIZATION_START:END}*/
        /** @type {?} */
        const toValidate = ["employee"];
        if (!toValidate.every((/**
         * @param {?} e
         * @return {?}
         */
        (e) => this.allPermissions[e] && this.allPermissions[e].visualizar))) {
            this.router.navigate(["forbidden"]);
        }
        /*{CA:VALIDATE_VISUALIZATION_END:START}*/
        /*{CA:VALIDATE_VISUALIZATION_END:END}*/
    }
    /**
     * @private
     * @return {?}
     */
    validLimitDaysBackwardScheduling() {
        return (/**
         * @param {?} control
         * @return {?}
         */
        (control) => {
            /** @type {?} */
            const originDate = control.get("originDate");
            /** @type {?} */
            const employee = control.get("employee");
            if (employee.value && originDate.value) {
                /** @type {?} */
                const limitDate = this.cacheLimitDaysBackwardScheduling.get(employee.value.employer.id);
                if (limitDate && moment$4(originDate.value).isBefore(limitDate, "day")) {
                    originDate.setErrors({ exceededLimit: { value: originDate.value } });
                }
                else {
                    removeErrorFromField(originDate, "exceededLimit");
                }
            }
            return null;
        });
    }
    /**
     * @private
     * @return {?}
     */
    startDateIsBeforeEndDate() {
        return (/**
         * @param {?} control
         * @return {?}
         */
        (control) => {
            /** @type {?} */
            const originDate = control.get("originDate");
            /** @type {?} */
            const destinationDate = control.get("destinationDate");
            startDateIsBeforeEndDateValidator(originDate, destinationDate);
            return null;
        });
    }
    /*{CA:CLASS_METHODS:END}*/
    /**
     * @private
     * @param {?} severity
     * @param {?} summary
     * @param {?} detail
     * @return {?}
     */
    addMessage(severity, summary, detail) {
        this.messageService.add({
            severity,
            summary: this.translate.instant(summary),
            detail: this.translate.instant(detail),
        });
    }
}
BridgeFormComponent.decorators = [
    { type: Component, args: [{
                template: "<div *ngIf=\"!customTemplate else customTemplate\">\n    <p-confirmDialog acceptLabel=\"{{'hcm_clocking_event_foundation.general.yes' | translate}}\" acceptIcon=\"\"\n        rejectLabel=\"{{'hcm_clocking_event_foundation.general.no' | translate}}\" rejectIcon=\"\">\n    </p-confirmDialog>\n    <form [formGroup]=\"formGroup\" novalidate>\n        <p-panel *sLoadingState=\"loading\" [styleClass]=\"lockedEmployee ? 'form-group sidebar-panel' : 'form-group'\" \n            [toggleable]=\"false\" [collapsed]=\"mainPanelCollapsed\" [showHeader]=\"!lockedEmployee\">\n            <p-header>\n                {{\"hcm_clocking_event_foundation.general.bridge_form_general_title\" | translate}}\n            </p-header>\n            <div class=\"ui-fluid\" *ngIf=\"!customFormFields else customFormFields\">\n                <div class=\"ui-g\">\n                    <div [attr.data-hidden]=\"true\" class=\"ui-g-12 ui-md-6\">\n                        <label for=\"id\">{{\"hcm_clocking_event_foundation.general.bridge_id\" | translate}}</label>\n                        <input #idFormInput type=\"text\" id=\"id\" name=\"id\" pInputText formControlName=\"id\" autocomplete=\"off\"\n                        />\n                    </div> \n                    <div [attr.data-hidden]=\"!allPermissions?.employee.visualizar\" class=\"ui-g-12 ui-md-6 required\">\n                        <label for=\"employee\">{{\"hcm_clocking_event_foundation.general.bridge_employee\" | translate}}</label>\n                        <s-lookup dataKey=\"id\" id=\"employee\" name=\"employee\" formControlName=\"employee\" [searchFields]=\"employeeSearchGridFields\"\n                        [searchGridFields]=\"employeeSearchGridFields\" [searchGridData]=\"employeeSearchGridData\"\n                        [multiple]=\"false\" [lookupSuggestions]=\"employeeLookupSuggestions\" (onLookupRequest)=\"onEmployeeLookupRequest($event)\"\n                        (onSearchRequest)=\"onEmployeeSearchRequest($event)\" lookupDisplayField=\"label\"\n                        [searchTotalRecords]=employeeSearchTotalRecords [searchTitle]=\"'hcm_clocking_event_foundation.general.bridge_employee_search_title' | translate\"\n                        [searchEmptyTitle]=\"'hcm_clocking_event_foundation.general.nothing_found' | translate\"\n                        [filterLabel]=\"'hcm_clocking_event_foundation.general.filter' | translate\" [filterTitle]=\"'hcm_clocking_event_foundation.general.filters' | translate\"\n                        [clearLabel]=\"'hcm_clocking_event_foundation.general.clear' | translate\" [cancelLabel]=\"'hcm_clocking_event_foundation.general.cancel' | translate\"\n                        [selectLabel]=\"'hcm_clocking_event_foundation.general.select' | translate\" [searchTotalRecordsLabel]=\"'hcm_clocking_event_foundation.general.total_records' | translate: {value: employeeSearchTotalRecords}\"></s-lookup>\n                        <s-control-errors [control]=\"formGroup.controls['employee']\"\n                        [errorMessages]=\"{\n                            required: 'hcm_clocking_event_foundation.general.error_required' | translate,\n                            hasNotCompanyClockingEventIndications: 'hcm_clocking_event_foundation.general.error_company_of_employee_need_time_evaluation_definition' | translate\n                        }\"\n                        ></s-control-errors>\n                    </div>\n                    <div class=\"ui-md-6\"></div>\n                    <div class=\"ui-g-12 ui-md-6 required\">\n                        <label for=\"originDate\">{{\"hcm_clocking_event_foundation.general.bridge_origin_date\" | translate}}</label>\n                        <p-calendar #originDateFormInput inputId=\"originDate\" name=\"originDate\" [showIcon]=\"true\" formControlName=\"originDate\"\n                            [locale]=\"localeConfig.calendar\" [dateFormat]=\"localeConfig.calendar.dateFormat\"></p-calendar>\n                        <s-control-errors [control]=\"formGroup.controls['originDate']\"\n                            [errorMessages]=\"{\n                                required: 'hcm_clocking_event_foundation.general.error_required' | translate,\n                                exceededLimit: 'hcm_clocking_event_foundation.general.error_exceeded_limit_days_backward_scheduling' | translate, \n                                startDateIsBeforeEndDate: 'hcm_clocking_event_foundation.general.error_origin_date_after_destination_date_to_start_date' | translate\n                            }\"\n                        ></s-control-errors>\n                    </div>\n                    <div class=\"ui-g-12 ui-md-6 required\">\n                        <label for=\"destinationDate\">{{\"hcm_clocking_event_foundation.general.bridge_destination_date\" | translate}}</label>\n                        <p-calendar #destinationDateFormInput inputId=\"destinationDate\" name=\"destinationDate\" [showIcon]=\"true\"\n                            formControlName=\"destinationDate\" [locale]=\"localeConfig.calendar\" [dateFormat]=\"localeConfig.calendar.dateFormat\"></p-calendar>\n                        <s-control-errors [control]=\"formGroup.controls['destinationDate']\"\n                            [errorMessages]=\"{\n                                required: 'hcm_clocking_event_foundation.general.error_required' | translate,\n                                startDateIsBeforeEndDate: 'hcm_clocking_event_foundation.general.error_origin_date_after_destination_date_to_end_date' | translate\n                            }\"\n                        ></s-control-errors>\n                    </div>\n                </div>\n            </div>\n            <s-custom-fields domain=\"hcm_clocking_event_foundation\" service=\"general\" entity=\"bridge\" formControlName=\"custom\"\n                [invalidErrorLabel]=\"'hcm_clocking_event_foundation.general.error_invalid' | translate\"></s-custom-fields>\n            <div class=\"ui-g\" *ngIf=\"!isNew() && !lockedEmployee\">\n                <div class=\"ui-g-12 ui-inputgroup\"> \n                    <label *ngIf=\"formGroup.get('createdBy').value !== ''\" style=\"color: #a3a3a3; margin-right: 2px;\">{{'hcm_clocking_event_foundation.general.created_by' | translate}} {{formGroup.get('createdBy').value}} {{'hcm_clocking_event_foundation.general.at_date' | translate}} {{formGroup.get('createdDate').value | date: 'dd/MM/yyyy'}} {{'hcm_clocking_event_foundation.general.at_time' | translate}} {{formGroup.get('createdDate').value | date: 'HH:mm'}}. </label>\n                    <label *ngIf=\"formGroup.get('lastModifiedBy').value !== ''\" style=\"color: #a3a3a3;\">{{'hcm_clocking_event_foundation.general.updated_by' | translate}} {{formGroup.get('lastModifiedBy').value}} {{'hcm_clocking_event_foundation.general.at_date' | translate}} {{formGroup.get('lastModifiedDate').value | date: 'dd/MM/yyyy'}} {{'hcm_clocking_event_foundation.general.at_time' | translate}} {{formGroup.get('lastModifiedDate').value | date: 'HH:mm'}}.</label>\n                </div>\n            </div>\n            <p-footer *ngIf=\"!lockedEmployee\">\n                <button id=\"save-button\" title=\"{{'hcm_clocking_event_foundation.general.save' | translate}} (Alt + Shift + S)\"\n                    type=\"submit\" pButton label=\"{{'hcm_clocking_event_foundation.general.save' | translate}}\"\n                    (click)=\"onSave()\" *ngIf=\"isNew() || permissions.editar\"></button>\n                <button id=\"delete-button\" title=\"{{'hcm_clocking_event_foundation.general.delete' | translate}} (Alt + Shift + X)\"\n                    type=\"button\" class=\"ui-button-secondary\" pButton label=\"{{'hcm_clocking_event_foundation.general.delete' | translate}}\"\n                    (click)=\"onDelete()\" *ngIf=\"!isNew() && permissions.excluir\" [disabled]=\"loading\"></button>\n                <button id=\"cancel-button\" title=\"{{'hcm_clocking_event_foundation.general.cancel' | translate}} (Alt + Shift + C)\"\n                    type=\"button\" class=\"ui-button-link\" pButton label=\"{{'hcm_clocking_event_foundation.general.cancel' | translate}}\"\n                    (click)=\"onCancel()\"></button>\n            </p-footer>\n        </p-panel>\n    </form>\n</div>\n<!--{CA:FILE_CONTENTS:START}-->\n<!--{CA:FILE_CONTENTS:END}-->\n",
                providers: [
                    ConfirmationService,
                ],
                selector: "cem-bridge-form",
                styles: [":host ::ng-deep .sidebar-panel{border:none!important;padding-left:0!important}"]
            }] }
];
/** @nocollapse */
BridgeFormComponent.ctorParameters = () => [
    { type: CompanyClockingEventIndicationsService },
    { type: BridgeService },
    { type: Router },
    { type: ActivatedRoute },
    { type: MessageService },
    { type: ConfirmationService },
    { type: FormBuilder },
    { type: TranslateService },
    { type: HotkeysService },
    { type: FieldCustomizationService },
    { type: FocusService },
    { type: EmployeeService }
];
BridgeFormComponent.propDecorators = {
    customTemplate: [{ type: ViewChild, args: ["customTemplate", { static: false },] }],
    customFormFields: [{ type: ViewChild, args: ["customFormFields", { static: false },] }],
    onSubmitObservable: [{ type: Input }],
    onLockedEmployeeChanges: [{ type: Input }],
    lockedEmployee: [{ type: Input }],
    onCloseObservable: [{ type: Output }]
};
if (false) {
    /** @type {?} */
    BridgeFormComponent.prototype.localeConfig;
    /** @type {?} */
    BridgeFormComponent.prototype.currencyLocaleOptions;
    /** @type {?} */
    BridgeFormComponent.prototype.permissions;
    /** @type {?} */
    BridgeFormComponent.prototype.allPermissions;
    /** @type {?} */
    BridgeFormComponent.prototype.formGroup;
    /** @type {?} */
    BridgeFormComponent.prototype.loading;
    /** @type {?} */
    BridgeFormComponent.prototype.mainPanelCollapsed;
    /** @type {?} */
    BridgeFormComponent.prototype.contractTypeOptions;
    /** @type {?} */
    BridgeFormComponent.prototype.employeeLookupSuggestions;
    /** @type {?} */
    BridgeFormComponent.prototype.employeeLookupDisplayFields;
    /** @type {?} */
    BridgeFormComponent.prototype.employeeAdvancedDisplayFields;
    /** @type {?} */
    BridgeFormComponent.prototype.employeeLookupSeparator;
    /** @type {?} */
    BridgeFormComponent.prototype.employeeSearchFields;
    /** @type {?} */
    BridgeFormComponent.prototype.employeeSearchGridFields;
    /** @type {?} */
    BridgeFormComponent.prototype.employeeSearchGridData;
    /** @type {?} */
    BridgeFormComponent.prototype.employeeSearchTotalRecords;
    /** @type {?} */
    BridgeFormComponent.prototype.customTemplate;
    /** @type {?} */
    BridgeFormComponent.prototype.customFormFields;
    /** @type {?} */
    BridgeFormComponent.prototype.cacheLimitDaysBackwardScheduling;
    /** @type {?} */
    BridgeFormComponent.prototype.onSubmitObservable;
    /** @type {?} */
    BridgeFormComponent.prototype.onLockedEmployeeChanges;
    /** @type {?} */
    BridgeFormComponent.prototype.lockedEmployee;
    /**
     * @type {?}
     * @private
     */
    BridgeFormComponent.prototype.onClose;
    /** @type {?} */
    BridgeFormComponent.prototype.onCloseObservable;
    /**
     * @type {?}
     * @private
     */
    BridgeFormComponent.prototype.routeParams;
    /**
     * @type {?}
     * @private
     */
    BridgeFormComponent.prototype.ngUnsubscribe;
    /**
     * @type {?}
     * @private
     */
    BridgeFormComponent.prototype.companyClockingEventIndicationsService;
    /**
     * @type {?}
     * @private
     */
    BridgeFormComponent.prototype.bridgeService;
    /**
     * @type {?}
     * @private
     */
    BridgeFormComponent.prototype.router;
    /**
     * @type {?}
     * @private
     */
    BridgeFormComponent.prototype.route;
    /**
     * @type {?}
     * @private
     */
    BridgeFormComponent.prototype.messageService;
    /**
     * @type {?}
     * @private
     */
    BridgeFormComponent.prototype.confirmationService;
    /**
     * @type {?}
     * @private
     */
    BridgeFormComponent.prototype.formBuilder;
    /**
     * @type {?}
     * @private
     */
    BridgeFormComponent.prototype.translate;
    /**
     * @type {?}
     * @private
     */
    BridgeFormComponent.prototype.hotkeysService;
    /**
     * @type {?}
     * @private
     */
    BridgeFormComponent.prototype.fieldCustomization;
    /**
     * @type {?}
     * @private
     */
    BridgeFormComponent.prototype.focusService;
    /**
     * @type {?}
     * @private
     */
    BridgeFormComponent.prototype.employeeService;
}

/**
 * @fileoverview added by tsickle
 * Generated from: lib/bridge/bridge-form.module.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class BridgeFormModule {
}
BridgeFormModule.decorators = [
    { type: NgModule, args: [{
                imports: [
                    LocaleModule.forChild(),
                    SharedScheduleModule,
                    CoreSchedulesHistoriesModule
                ],
                declarations: [
                    BridgeFormComponent
                ],
                exports: [
                    BridgeFormComponent
                ]
            },] }
];

/**
 * @fileoverview added by tsickle
 * Generated from: core/dtos/employee-date.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/**
 * @record
 */
function EmployeeDate() { }
if (false) {
    /** @type {?} */
    EmployeeDate.prototype.evaluationDate;
    /** @type {?} */
    EmployeeDate.prototype.employeeId;
}

/**
 * @fileoverview added by tsickle
 * Generated from: core/entities/bridge/bridge-dto.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/**
 * @record
 */
function BridgeDto() { }
if (false) {
    /** @type {?|undefined} */
    BridgeDto.prototype.id;
    /** @type {?} */
    BridgeDto.prototype.employee;
    /** @type {?} */
    BridgeDto.prototype.originDate;
    /** @type {?} */
    BridgeDto.prototype.destinationDate;
    /** @type {?|undefined} */
    BridgeDto.prototype.createdBy;
    /** @type {?|undefined} */
    BridgeDto.prototype.createdDate;
    /** @type {?|undefined} */
    BridgeDto.prototype.lastModifiedBy;
    /** @type {?|undefined} */
    BridgeDto.prototype.lastModifiedDate;
    /** @type {?|undefined} */
    BridgeDto.prototype.custom;
}

/**
 * @fileoverview added by tsickle
 * Generated from: core/entities/bridge/index.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

/**
 * @fileoverview added by tsickle
 * Generated from: core/entities/situation/situation.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/*{CA:PACKAGE_IMPORTS:START}*/
/** @type {?} */
const moment$5 = moment_;
// @HACK Necessary because of https://github.com/rollup/rollup/issues/670
/*{CA:PACKAGE_IMPORTS:END}*/
class Situation {
    constructor() {
        this.deleted = false;
        /*{CA:CLASS_METHODS:START}*/
        /*{CA:CLASS_METHODS:END}*/
    }
    /*{CA:CLASS_ATTRIBUTES:START}*/
    /*{CA:CLASS_ATTRIBUTES:END}*/
    /**
     * @param {?} situationDto
     * @param {?=} originEntity
     * @return {?}
     */
    static fromDto(situationDto, originEntity) {
        /** @type {?} */
        const model = Object.assign({}, situationDto);
        model.createdDate = model.createdDate && moment$5(model.createdDate).toDate();
        model.lastModifiedDate = model.lastModifiedDate && moment$5(model.lastModifiedDate).toDate();
        /** @type {?} */
        const lookupSeparator = " - ";
        /** @type {?} */
        const displayFields = ["code", "name"];
        model.label = displayFields.map((/**
         * @param {?} field
         * @return {?}
         */
        field => model[field])).join(lookupSeparator);
        return (/** @type {?} */ (model));
    }
    /**
     * @param {?} situation
     * @param {?=} originEntity
     * @return {?}
     */
    static toDto(situation, originEntity) {
        /** @type {?} */
        const dto = Object.assign({}, situation);
        dto.createdDate = dto.createdDate && moment$5(dto.createdDate).format();
        dto.lastModifiedDate = dto.lastModifiedDate && moment$5(dto.lastModifiedDate).format();
        delete dto.label;
        return dto;
    }
}
if (false) {
    /** @type {?} */
    Situation.prototype.id;
    /** @type {?} */
    Situation.prototype.code;
    /** @type {?} */
    Situation.prototype.name;
    /** @type {?} */
    Situation.prototype.deleted;
    /** @type {?} */
    Situation.prototype.extIntSts;
    /** @type {?} */
    Situation.prototype.extIntMsg;
    /** @type {?} */
    Situation.prototype.createdBy;
    /** @type {?} */
    Situation.prototype.createdDate;
    /** @type {?} */
    Situation.prototype.lastModifiedBy;
    /** @type {?} */
    Situation.prototype.lastModifiedDate;
    /** @type {?} */
    Situation.prototype.custom;
}

/**
 * @fileoverview added by tsickle
 * Generated from: core/entities/time-evaluation-definition/time-evaluation-definition.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/*{CA:PACKAGE_IMPORTS:START}*/
/*{CA:PACKAGE_IMPORTS:END}*/
/*{CA:PROJECT_IMPORTS:START}*/
/** @type {?} */
const moment$6 = moment_;
// @HACK Necessary because of https://github.com/rollup/rollup/issues/670
/*{CA:PROJECT_IMPORTS:END}*/
class TimeEvaluationDefinition {
    /*{CA:CLASS_ATTRIBUTES:START}*/
    /*{CA:CLASS_ATTRIBUTES:END}*/
    /**
     * @param {?} timeEvaluationDefinitionDto
     * @param {?=} originEntity
     * @return {?}
     */
    static fromDto(timeEvaluationDefinitionDto, originEntity) {
        /** @type {?} */
        const model = Object.assign({}, timeEvaluationDefinitionDto);
        model.createdDate = model.createdDate && moment$6(model.createdDate).toDate();
        model.lastModifiedDate = model.lastModifiedDate && moment$6(model.lastModifiedDate).toDate();
        /** @type {?} */
        const lookupSeparator = " - ";
        /** @type {?} */
        const displayFields = ["code", "name"];
        model.label = displayFields.map((/**
         * @param {?} field
         * @return {?}
         */
        field => model[field])).join(lookupSeparator);
        if (originEntity !== "Situation" && model.incompleteJourneySituation)
            model.incompleteJourneySituation = Situation.fromDto(model.incompleteJourneySituation, "TimeEvaluationDefinition");
        return (/** @type {?} */ (model));
    }
    /**
     * @param {?} timeEvaluationDefinition
     * @param {?=} originEntity
     * @return {?}
     */
    static toDto(timeEvaluationDefinition, originEntity) {
        /** @type {?} */
        const dto = Object.assign({}, timeEvaluationDefinition);
        dto.createdDate = dto.createdDate && moment$6(dto.createdDate).format();
        dto.lastModifiedDate = dto.lastModifiedDate && moment$6(dto.lastModifiedDate).format();
        delete dto.label;
        if (originEntity !== "Situation" && dto.incompleteJourneySituation)
            dto.incompleteJourneySituation = Situation.toDto(dto.incompleteJourneySituation, "TimeEvaluationDefinition");
        return dto;
    }
}
if (false) {
    /** @type {?} */
    TimeEvaluationDefinition.prototype.id;
    /** @type {?} */
    TimeEvaluationDefinition.prototype.code;
    /** @type {?} */
    TimeEvaluationDefinition.prototype.name;
    /** @type {?} */
    TimeEvaluationDefinition.prototype.useWorkscheduleDayOff;
    /** @type {?} */
    TimeEvaluationDefinition.prototype.verifiedDaysControl;
    /** @type {?} */
    TimeEvaluationDefinition.prototype.controlAdjustmentReason;
    /** @type {?} */
    TimeEvaluationDefinition.prototype.controlObservation;
    /** @type {?} */
    TimeEvaluationDefinition.prototype.daysResume;
    /** @type {?} */
    TimeEvaluationDefinition.prototype.clockingEventTolerance;
    /** @type {?} */
    TimeEvaluationDefinition.prototype.retroactiveAdjustment;
    /** @type {?} */
    TimeEvaluationDefinition.prototype.evaluateIncompleteJourney;
    /** @type {?} */
    TimeEvaluationDefinition.prototype.incompleteJourneySituation;
    /** @type {?} */
    TimeEvaluationDefinition.prototype.numberOfDaysAdjustment;
    /** @type {?} */
    TimeEvaluationDefinition.prototype.calculateHolidayAbsenceRotationWorkshift;
    /** @type {?} */
    TimeEvaluationDefinition.prototype.considerClockingEventInterval;
    /** @type {?} */
    TimeEvaluationDefinition.prototype.clockingEventInterval;
    /** @type {?} */
    TimeEvaluationDefinition.prototype.schedulingOverlapsHoliday;
    /** @type {?} */
    TimeEvaluationDefinition.prototype.limitDaysBackwardScheduling;
    /** @type {?} */
    TimeEvaluationDefinition.prototype.bridgeOverlapsWorkscheduleChange;
    /** @type {?} */
    TimeEvaluationDefinition.prototype.allowClockingEventModificationBeforeTransference;
    /** @type {?} */
    TimeEvaluationDefinition.prototype.calculateReadiness;
    /** @type {?} */
    TimeEvaluationDefinition.prototype.discountHoursWorkedReadiness;
    /** @type {?} */
    TimeEvaluationDefinition.prototype.expirationDays;
    /** @type {?} */
    TimeEvaluationDefinition.prototype.limitOfDaysAfterPointClosing;
    /** @type {?} */
    TimeEvaluationDefinition.prototype.blockPendingAfterExpires;
    /** @type {?} */
    TimeEvaluationDefinition.prototype.allowsTakeLedgerPending;
    /** @type {?} */
    TimeEvaluationDefinition.prototype.allowsCompleteUntreatedPending;
    /** @type {?} */
    TimeEvaluationDefinition.prototype.createdBy;
    /** @type {?} */
    TimeEvaluationDefinition.prototype.createdDate;
    /** @type {?} */
    TimeEvaluationDefinition.prototype.lastModifiedBy;
    /** @type {?} */
    TimeEvaluationDefinition.prototype.lastModifiedDate;
    /** @type {?} */
    TimeEvaluationDefinition.prototype.custom;
}

/**
 * @fileoverview added by tsickle
 * Generated from: core/entities/time-evaluation-situation-definition/time-evaluation-situation-definition.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/*{CA:PACKAGE_IMPORTS:START}*/
/** @type {?} */
const moment$7 = moment_;
// @HACK Necessary because of https://github.com/rollup/rollup/issues/670
/*{CA:PACKAGE_IMPORTS:END}*/
class TimeEvaluationSituationDefinition {
    /*{CA:CLASS_ATTRIBUTES:START}*/
    /*{CA:CLASS_ATTRIBUTES:END}*/
    /**
     * @param {?} timeEvaluationSituationDefinitionDto
     * @param {?=} originEntity
     * @return {?}
     */
    static fromDto(timeEvaluationSituationDefinitionDto, originEntity) {
        /** @type {?} */
        const model = Object.assign({}, timeEvaluationSituationDefinitionDto);
        model.createdDate = model.createdDate && moment$7(model.createdDate).toDate();
        model.lastModifiedDate = model.lastModifiedDate && moment$7(model.lastModifiedDate).toDate();
        /** @type {?} */
        const lookupSeparator = " - ";
        /** @type {?} */
        const displayFields = ["code", "name"];
        model.label = displayFields.map((/**
         * @param {?} field
         * @return {?}
         */
        field => model[field])).join(lookupSeparator);
        return (/** @type {?} */ (model));
    }
    /**
     * @param {?} timeEvaluationSituationDefinition
     * @param {?=} originEntity
     * @return {?}
     */
    static toDto(timeEvaluationSituationDefinition, originEntity) {
        /** @type {?} */
        const dto = Object.assign({}, timeEvaluationSituationDefinition);
        dto.createdDate = dto.createdDate && moment$7(dto.createdDate).format();
        dto.lastModifiedDate = dto.lastModifiedDate && moment$7(dto.lastModifiedDate).format();
        delete dto.label;
        return dto;
    }
}
if (false) {
    /** @type {?} */
    TimeEvaluationSituationDefinition.prototype.id;
    /** @type {?} */
    TimeEvaluationSituationDefinition.prototype.code;
    /** @type {?} */
    TimeEvaluationSituationDefinition.prototype.name;
    /** @type {?} */
    TimeEvaluationSituationDefinition.prototype.createdBy;
    /** @type {?} */
    TimeEvaluationSituationDefinition.prototype.createdDate;
    /** @type {?} */
    TimeEvaluationSituationDefinition.prototype.lastModifiedBy;
    /** @type {?} */
    TimeEvaluationSituationDefinition.prototype.lastModifiedDate;
    /** @type {?} */
    TimeEvaluationSituationDefinition.prototype.custom;
}

/**
 * @fileoverview added by tsickle
 * Generated from: core/entities/company-clocking-event-indications/company-clocking-event-indications.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/** @type {?} */
const moment$8 = moment_;
// @HACK Necessary because of https://github.com/rollup/rollup/issues/670
class CompanyClockingEventIndications {
    /**
     * @param {?} companyClockingEventIndicationsDto
     * @param {?=} originEntity
     * @return {?}
     */
    static fromDto(companyClockingEventIndicationsDto, originEntity) {
        /** @type {?} */
        const model = Object.assign({}, companyClockingEventIndicationsDto);
        model.createdDate = model.createdDate && moment$8(model.createdDate).toDate();
        model.lastModifiedDate = model.lastModifiedDate && moment$8(model.lastModifiedDate).toDate();
        /** @type {?} */
        const lookupSeparator = " - ";
        /** @type {?} */
        const displayFields = [
            "timeEvaluationDefinition.code",
            "timeEvaluationDefinition.name",
            "timeEvaluationSituationDefinition.code",
            "timeEvaluationSituationDefinition.name",
        ];
        model.label = displayFields.map((/**
         * @param {?} field
         * @return {?}
         */
        field => model[field])).join(lookupSeparator);
        if (originEntity !== "TimeEvaluationDefinition" && model.timeEvaluationDefinition)
            model.timeEvaluationDefinition = TimeEvaluationDefinition.fromDto(model.timeEvaluationDefinition, "CompanyClockingEventIndications");
        if (originEntity !== "TimeEvaluationSituationDefinition" && model.timeEvaluationSituationDefinition)
            model.timeEvaluationSituationDefinition = TimeEvaluationSituationDefinition.fromDto(model.timeEvaluationSituationDefinition, "CompanyClockingEventIndications");
        return (/** @type {?} */ (model));
    }
    /**
     * @param {?} companyClockingEventIndications
     * @param {?=} originEntity
     * @return {?}
     */
    static toDto(companyClockingEventIndications, originEntity) {
        /** @type {?} */
        const dto = Object.assign({}, companyClockingEventIndications);
        dto.createdDate = dto.createdDate && moment$8(dto.createdDate).format();
        dto.lastModifiedDate = dto.lastModifiedDate && moment$8(dto.lastModifiedDate).format();
        delete dto.label;
        if (originEntity !== "TimeEvaluationDefinition" && dto.timeEvaluationDefinition)
            dto.timeEvaluationDefinition = TimeEvaluationDefinition.toDto(dto.timeEvaluationDefinition, "CompanyClockingEventIndications");
        if (originEntity !== "TimeEvaluationSituationDefinition" && dto.timeEvaluationSituationDefinition)
            dto.timeEvaluationSituationDefinition = TimeEvaluationSituationDefinition.toDto(dto.timeEvaluationSituationDefinition, "CompanyClockingEventIndications");
        return dto;
    }
}
if (false) {
    /** @type {?} */
    CompanyClockingEventIndications.prototype.id;
    /** @type {?} */
    CompanyClockingEventIndications.prototype.timeEvaluationDefinition;
    /** @type {?} */
    CompanyClockingEventIndications.prototype.timeEvaluationSituationDefinition;
    /** @type {?} */
    CompanyClockingEventIndications.prototype.createdBy;
    /** @type {?} */
    CompanyClockingEventIndications.prototype.createdDate;
    /** @type {?} */
    CompanyClockingEventIndications.prototype.lastModifiedBy;
    /** @type {?} */
    CompanyClockingEventIndications.prototype.lastModifiedDate;
    /** @type {?} */
    CompanyClockingEventIndications.prototype.custom;
}

/**
 * @fileoverview added by tsickle
 * Generated from: core/entities/company-clocking-event-indications/company-clocking-event-indications-dto.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/**
 * @record
 */
function CompanyClockingEventIndicationsDto() { }
if (false) {
    /** @type {?|undefined} */
    CompanyClockingEventIndicationsDto.prototype.id;
    /** @type {?|undefined} */
    CompanyClockingEventIndicationsDto.prototype.company;
    /** @type {?} */
    CompanyClockingEventIndicationsDto.prototype.timeEvaluationDefinition;
    /** @type {?} */
    CompanyClockingEventIndicationsDto.prototype.timeEvaluationSituationDefinition;
    /** @type {?|undefined} */
    CompanyClockingEventIndicationsDto.prototype.createdBy;
    /** @type {?|undefined} */
    CompanyClockingEventIndicationsDto.prototype.createdDate;
    /** @type {?|undefined} */
    CompanyClockingEventIndicationsDto.prototype.lastModifiedBy;
    /** @type {?|undefined} */
    CompanyClockingEventIndicationsDto.prototype.lastModifiedDate;
    /** @type {?|undefined} */
    CompanyClockingEventIndicationsDto.prototype.custom;
}

/**
 * @fileoverview added by tsickle
 * Generated from: core/entities/company-clocking-event-indications/index.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

/**
 * @fileoverview added by tsickle
 * Generated from: core/entities/e-001-pes/e-001-pes-dto.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/**
 * @record
 */
function E001PesDto() { }
if (false) {
    /** @type {?|undefined} */
    E001PesDto.prototype.id;
    /** @type {?} */
    E001PesDto.prototype.nomPes;
    /** @type {?|undefined} */
    E001PesDto.prototype.excluido;
    /** @type {?|undefined} */
    E001PesDto.prototype.extIntSts;
    /** @type {?|undefined} */
    E001PesDto.prototype.extIntMsg;
    /** @type {?|undefined} */
    E001PesDto.prototype.createdBy;
    /** @type {?|undefined} */
    E001PesDto.prototype.createdDate;
    /** @type {?|undefined} */
    E001PesDto.prototype.lastModifiedBy;
    /** @type {?|undefined} */
    E001PesDto.prototype.lastModifiedDate;
    /** @type {?|undefined} */
    E001PesDto.prototype.custom;
}

/**
 * @fileoverview added by tsickle
 * Generated from: core/entities/e-001-pes/index.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

/**
 * @fileoverview added by tsickle
 * Generated from: core/entities/employee/employee-dto.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/**
 * @record
 */
function EmployeeDto() { }
if (false) {
    /** @type {?|undefined} */
    EmployeeDto.prototype.id;
    /** @type {?} */
    EmployeeDto.prototype.code;
    /** @type {?|undefined} */
    EmployeeDto.prototype.employmentRelationship;
    /** @type {?|undefined} */
    EmployeeDto.prototype.employer;
    /** @type {?|undefined} */
    EmployeeDto.prototype.person;
    /** @type {?|undefined} */
    EmployeeDto.prototype.hireDate;
    /** @type {?|undefined} */
    EmployeeDto.prototype.dismissalDate;
    /** @type {?|undefined} */
    EmployeeDto.prototype.deleted;
    /** @type {?|undefined} */
    EmployeeDto.prototype.extIntSts;
    /** @type {?|undefined} */
    EmployeeDto.prototype.extIntMsg;
    /** @type {?|undefined} */
    EmployeeDto.prototype.createdBy;
    /** @type {?|undefined} */
    EmployeeDto.prototype.createdDate;
    /** @type {?|undefined} */
    EmployeeDto.prototype.lastModifiedBy;
    /** @type {?|undefined} */
    EmployeeDto.prototype.lastModifiedDate;
    /** @type {?|undefined} */
    EmployeeDto.prototype.custom;
}

/**
 * @fileoverview added by tsickle
 * Generated from: core/entities/employee/index.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

/**
 * @fileoverview added by tsickle
 * Generated from: core/entities/situation/situation-dto.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/*{CA:PACKAGE_IMPORTS:START}*/
/*{CA:PACKAGE_IMPORTS:END}*/
/*{CA:PROJECT_IMPORTS:START}*/
/*{CA:PROJECT_IMPORTS:END}*/
/**
 * @record
 */
function SituationDto() { }
if (false) {
    /** @type {?|undefined} */
    SituationDto.prototype.id;
    /** @type {?} */
    SituationDto.prototype.code;
    /** @type {?} */
    SituationDto.prototype.name;
    /** @type {?|undefined} */
    SituationDto.prototype.deleted;
    /** @type {?|undefined} */
    SituationDto.prototype.extIntSts;
    /** @type {?|undefined} */
    SituationDto.prototype.extIntMsg;
    /** @type {?|undefined} */
    SituationDto.prototype.createdBy;
    /** @type {?|undefined} */
    SituationDto.prototype.createdDate;
    /** @type {?|undefined} */
    SituationDto.prototype.lastModifiedBy;
    /** @type {?|undefined} */
    SituationDto.prototype.lastModifiedDate;
    /** @type {?|undefined} */
    SituationDto.prototype.custom;
}

/**
 * @fileoverview added by tsickle
 * Generated from: core/entities/situation/index.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

/**
 * @fileoverview added by tsickle
 * Generated from: core/entities/time-evaluation-definition/time-evaluation-definition-dto.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/*{CA:PACKAGE_IMPORTS:START}*/
/*{CA:PACKAGE_IMPORTS:END}*/
/*{CA:PROJECT_IMPORTS:START}*/
/*{CA:PROJECT_IMPORTS:END}*/
/**
 * @record
 */
function TimeEvaluationDefinitionDto() { }
if (false) {
    /** @type {?|undefined} */
    TimeEvaluationDefinitionDto.prototype.id;
    /** @type {?} */
    TimeEvaluationDefinitionDto.prototype.code;
    /** @type {?} */
    TimeEvaluationDefinitionDto.prototype.name;
    /** @type {?|undefined} */
    TimeEvaluationDefinitionDto.prototype.useWorkscheduleDayOff;
    /** @type {?|undefined} */
    TimeEvaluationDefinitionDto.prototype.verifiedDaysControl;
    /** @type {?|undefined} */
    TimeEvaluationDefinitionDto.prototype.controlAdjustmentReason;
    /** @type {?|undefined} */
    TimeEvaluationDefinitionDto.prototype.controlObservation;
    /** @type {?|undefined} */
    TimeEvaluationDefinitionDto.prototype.daysResume;
    /** @type {?|undefined} */
    TimeEvaluationDefinitionDto.prototype.clockingEventTolerance;
    /** @type {?|undefined} */
    TimeEvaluationDefinitionDto.prototype.retroactiveAdjustment;
    /** @type {?|undefined} */
    TimeEvaluationDefinitionDto.prototype.evaluateIncompleteJourney;
    /** @type {?|undefined} */
    TimeEvaluationDefinitionDto.prototype.incompleteJourneySituation;
    /** @type {?|undefined} */
    TimeEvaluationDefinitionDto.prototype.numberOfDaysAdjustment;
    /** @type {?|undefined} */
    TimeEvaluationDefinitionDto.prototype.calculateHolidayAbsenceRotationWorkshift;
    /** @type {?|undefined} */
    TimeEvaluationDefinitionDto.prototype.considerClockingEventInterval;
    /** @type {?|undefined} */
    TimeEvaluationDefinitionDto.prototype.clockingEventInterval;
    /** @type {?|undefined} */
    TimeEvaluationDefinitionDto.prototype.schedulingOverlapsHoliday;
    /** @type {?|undefined} */
    TimeEvaluationDefinitionDto.prototype.limitDaysBackwardScheduling;
    /** @type {?|undefined} */
    TimeEvaluationDefinitionDto.prototype.bridgeOverlapsWorkscheduleChange;
    /** @type {?|undefined} */
    TimeEvaluationDefinitionDto.prototype.allowClockingEventModificationBeforeTransference;
    /** @type {?|undefined} */
    TimeEvaluationDefinitionDto.prototype.calculateReadiness;
    /** @type {?|undefined} */
    TimeEvaluationDefinitionDto.prototype.discountHoursWorkedReadiness;
    /** @type {?|undefined} */
    TimeEvaluationDefinitionDto.prototype.expirationDays;
    /** @type {?|undefined} */
    TimeEvaluationDefinitionDto.prototype.limitOfDaysAfterPointClosing;
    /** @type {?|undefined} */
    TimeEvaluationDefinitionDto.prototype.blockPendingAfterExpires;
    /** @type {?|undefined} */
    TimeEvaluationDefinitionDto.prototype.allowsTakeLedgerPending;
    /** @type {?|undefined} */
    TimeEvaluationDefinitionDto.prototype.allowsCompleteUntreatedPending;
    /** @type {?|undefined} */
    TimeEvaluationDefinitionDto.prototype.createdBy;
    /** @type {?|undefined} */
    TimeEvaluationDefinitionDto.prototype.createdDate;
    /** @type {?|undefined} */
    TimeEvaluationDefinitionDto.prototype.lastModifiedBy;
    /** @type {?|undefined} */
    TimeEvaluationDefinitionDto.prototype.lastModifiedDate;
    /** @type {?|undefined} */
    TimeEvaluationDefinitionDto.prototype.custom;
}

/**
 * @fileoverview added by tsickle
 * Generated from: core/entities/time-evaluation-definition/index.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

/**
 * @fileoverview added by tsickle
 * Generated from: core/entities/time-evaluation-situation-definition/time-evaluation-situation-definition-dto.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/*{CA:PACKAGE_IMPORTS:START}*/
/*{CA:PACKAGE_IMPORTS:END}*/
/*{CA:PROJECT_IMPORTS:START}*/
/*{CA:PROJECT_IMPORTS:END}*/
/**
 * @record
 */
function TimeEvaluationSituationDefinitionDto() { }
if (false) {
    /** @type {?|undefined} */
    TimeEvaluationSituationDefinitionDto.prototype.id;
    /** @type {?} */
    TimeEvaluationSituationDefinitionDto.prototype.code;
    /** @type {?} */
    TimeEvaluationSituationDefinitionDto.prototype.name;
    /** @type {?|undefined} */
    TimeEvaluationSituationDefinitionDto.prototype.createdBy;
    /** @type {?|undefined} */
    TimeEvaluationSituationDefinitionDto.prototype.createdDate;
    /** @type {?|undefined} */
    TimeEvaluationSituationDefinitionDto.prototype.lastModifiedBy;
    /** @type {?|undefined} */
    TimeEvaluationSituationDefinitionDto.prototype.lastModifiedDate;
    /** @type {?|undefined} */
    TimeEvaluationSituationDefinitionDto.prototype.custom;
}

/**
 * @fileoverview added by tsickle
 * Generated from: core/entities/time-evaluation-situation-definition/index.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

/**
 * @fileoverview added by tsickle
 * Generated from: core/entities/situation-clocking-event/situation-clocking-event.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/*{CA:PROJECT_IMPORTS:START}*/
/** @type {?} */
const moment$9 = moment_;
// @HACK Necessary because of https://github.com/rollup/rollup/issues/670
/*{CA:PROJECT_IMPORTS:END}*/
class SituationClockingEvent {
    constructor() {
        this.daytimeSituation = false;
        /*{CA:CLASS_METHODS:START}*/
        /*{CA:CLASS_METHODS:END}*/
    }
    /*{CA:CLASS_ATTRIBUTES:START}*/
    /*{CA:CLASS_ATTRIBUTES:END}*/
    /**
     * @param {?} situationClockingEventDto
     * @param {?=} originEntity
     * @return {?}
     */
    static fromDto(situationClockingEventDto, originEntity) {
        /** @type {?} */
        const model = Object.assign({}, situationClockingEventDto);
        model.createdDate = model.createdDate && moment$9(model.createdDate).toDate();
        model.lastModifiedDate = model.lastModifiedDate && moment$9(model.lastModifiedDate).toDate();
        /** @type {?} */
        const lookupSeparator = " - ";
        /** @type {?} */
        const displayFields = [
            "id",
            "complementarySituation.code",
            "complementarySituation.name",
            "exceptionSituation",
            "mandatoryAdjustmentReason",
            "daytimeSituation",
            "convertNightHours",
            "obligateAttachmentOnLeave",
            "createdBy",
            "createdDate",
            "lastModifiedBy",
            "lastModifiedDate",
        ];
        model.label = displayFields.map((/**
         * @param {?} field
         * @return {?}
         */
        field => model[field])).join(lookupSeparator);
        if (originEntity !== "Situation" && model.situation)
            model.situation = Situation.fromDto(model.situation, "SituationClockingEvent");
        if (originEntity !== "Situation" && model.complementarySituation)
            model.complementarySituation = Situation.fromDto(model.complementarySituation, "SituationClockingEvent");
        return (/** @type {?} */ (model));
    }
    /**
     * @param {?} situationClockingEvent
     * @param {?=} originEntity
     * @return {?}
     */
    static toDto(situationClockingEvent, originEntity) {
        /** @type {?} */
        const dto = Object.assign({}, situationClockingEvent);
        dto.createdDate = dto.createdDate && moment$9(dto.createdDate).format();
        dto.lastModifiedDate = dto.lastModifiedDate && moment$9(dto.lastModifiedDate).format();
        delete dto.label;
        if (originEntity !== "Situation" && dto.situation)
            dto.situation = Situation.toDto(dto.situation, "SituationClockingEvent");
        if (originEntity !== "Situation" && dto.complementarySituation)
            dto.complementarySituation = Situation.toDto(dto.complementarySituation, "SituationClockingEvent");
        return dto;
    }
}
if (false) {
    /** @type {?} */
    SituationClockingEvent.prototype.id;
    /** @type {?} */
    SituationClockingEvent.prototype.situation;
    /** @type {?} */
    SituationClockingEvent.prototype.complementarySituation;
    /** @type {?} */
    SituationClockingEvent.prototype.exceptionSituation;
    /** @type {?} */
    SituationClockingEvent.prototype.mandatoryAdjustmentReason;
    /** @type {?} */
    SituationClockingEvent.prototype.daytimeSituation;
    /** @type {?} */
    SituationClockingEvent.prototype.convertNightHours;
    /** @type {?} */
    SituationClockingEvent.prototype.obligateAttachmentOnLeave;
    /** @type {?} */
    SituationClockingEvent.prototype.createdBy;
    /** @type {?} */
    SituationClockingEvent.prototype.createdDate;
    /** @type {?} */
    SituationClockingEvent.prototype.lastModifiedBy;
    /** @type {?} */
    SituationClockingEvent.prototype.lastModifiedDate;
    /** @type {?} */
    SituationClockingEvent.prototype.custom;
}

/**
 * @fileoverview added by tsickle
 * Generated from: core/entities/time-evaluation-situation-definition-history/time-evaluation-situation-definition-history.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/*{CA:PACKAGE_IMPORTS:START}*/
/** @type {?} */
const moment$a = moment_;
/*{CA:PROJECT_IMPORTS:START}*/
/*{CA:PROJECT_IMPORTS:END}*/
class TimeEvaluationSituationDefinitionHistory {
    /*{CA:CLASS_ATTRIBUTES:START}*/
    /*{CA:CLASS_ATTRIBUTES:END}*/
    /**
     * @param {?} timeEvaluationSituationDefinitionHistoryDto
     * @param {?=} originEntity
     * @return {?}
     */
    static fromDto(timeEvaluationSituationDefinitionHistoryDto, originEntity) {
        /** @type {?} */
        const model = Object.assign({}, timeEvaluationSituationDefinitionHistoryDto);
        model.startDate = model.startDate && moment$a(model.startDate).toDate();
        model.endDate = model.endDate && moment$a(model.endDate).toDate();
        model.createdDate = model.createdDate && moment$a(model.createdDate).toDate();
        model.lastModifiedDate = model.lastModifiedDate && moment$a(model.lastModifiedDate).toDate();
        if (model.normalOvertimeSeparationLimit && model.normalOvertimeSeparationLimit !== undefined) {
            model.normalOvertimeSeparationLimit = convertMinutesToTime(model.normalOvertimeSeparationLimit.toString());
        }
        if (model.overtimeSeparationLimitDuringRest && model.normalOvertimeSeparationLimit !== undefined) {
            model.overtimeSeparationLimitDuringRest = convertMinutesToTime(model.overtimeSeparationLimitDuringRest.toString());
        }
        if (model.overtimeSeparationLimitDuringCompensatedDays && model.overtimeSeparationLimitDuringCompensatedDays !== undefined) {
            model.overtimeSeparationLimitDuringCompensatedDays = convertMinutesToTime(model.overtimeSeparationLimitDuringCompensatedDays.toString());
        }
        if (model.overtimeSeparationLimitDuringHoliday && model.overtimeSeparationLimitDuringHoliday !== undefined) {
            model.overtimeSeparationLimitDuringHoliday = convertMinutesToTime(model.overtimeSeparationLimitDuringHoliday.toString());
        }
        if (model.overtimeSeparationLimitDuringDayOff && model.overtimeSeparationLimitDuringDayOff !== undefined) {
            model.overtimeSeparationLimitDuringDayOff = convertMinutesToTime(model.overtimeSeparationLimitDuringDayOff.toString());
        }
        /** @type {?} */
        const lookupSeparator = " - ";
        /** @type {?} */
        const displayFields = ["situationDefinition.code", "situationDefinition.name", "startDate", "endDate"];
        model.label = displayFields.map((/**
         * @param {?} field
         * @return {?}
         */
        field => model[field])).join(lookupSeparator);
        if (originEntity !== "TimeEvaluationSituationDefinition" && model.situationDefinition)
            model.situationDefinition = TimeEvaluationSituationDefinition.fromDto(model.situationDefinition, "TimeEvaluationSituationDefinitionHistory");
        if (originEntity !== "SituationClockingEvent" && model.workSituation)
            model.workSituation = SituationClockingEvent.fromDto(model.workSituation, "TimeEvaluationSituationDefinitionHistory");
        if (originEntity !== "SituationClockingEvent" && model.nightShiftWorkPremium)
            model.nightShiftWorkPremium = SituationClockingEvent.fromDto(model.nightShiftWorkPremium, "TimeEvaluationSituationDefinitionHistory");
        if (originEntity !== "SituationClockingEvent" && model.invalidEventsSituation)
            model.invalidEventsSituation = SituationClockingEvent.fromDto(model.invalidEventsSituation, "TimeEvaluationSituationDefinitionHistory");
        if (originEntity !== "SituationClockingEvent" && model.vacationPaidLeaveSituation)
            model.vacationPaidLeaveSituation = SituationClockingEvent.fromDto(model.vacationPaidLeaveSituation, "TimeEvaluationSituationDefinitionHistory");
        if (originEntity !== "SituationClockingEvent" && model.dailyRestViolationSituation)
            model.dailyRestViolationSituation = SituationClockingEvent.fromDto(model.dailyRestViolationSituation, "TimeEvaluationSituationDefinitionHistory");
        if (originEntity !== "SituationClockingEvent" && model.workBreakViolationSituation)
            model.workBreakViolationSituation = SituationClockingEvent.fromDto(model.workBreakViolationSituation, "TimeEvaluationSituationDefinitionHistory");
        if (originEntity !== "SituationClockingEvent" && model.absenceSituation)
            model.absenceSituation = SituationClockingEvent.fromDto(model.absenceSituation, "TimeEvaluationSituationDefinitionHistory");
        if (originEntity !== "SituationClockingEvent" && model.tardinessSituation)
            model.tardinessSituation = SituationClockingEvent.fromDto(model.tardinessSituation, "TimeEvaluationSituationDefinitionHistory");
        if (originEntity !== "SituationClockingEvent" && model.intermediateLeaveSituation)
            model.intermediateLeaveSituation = SituationClockingEvent.fromDto(model.intermediateLeaveSituation, "TimeEvaluationSituationDefinitionHistory");
        if (originEntity !== "SituationClockingEvent" && model.earlyLeaveSituation)
            model.earlyLeaveSituation = SituationClockingEvent.fromDto(model.earlyLeaveSituation, "TimeEvaluationSituationDefinitionHistory");
        if (originEntity !== "SituationClockingEvent" && model.absenceSituationOnRelayScheduleHolidays)
            model.absenceSituationOnRelayScheduleHolidays = SituationClockingEvent.fromDto(model.absenceSituationOnRelayScheduleHolidays, "TimeEvaluationSituationDefinitionHistory");
        if (originEntity !== "SituationClockingEvent" && model.unauthorizedOvertime)
            model.unauthorizedOvertime = SituationClockingEvent.fromDto(model.unauthorizedOvertime, "TimeEvaluationSituationDefinitionHistory");
        if (originEntity !== "SituationClockingEvent" && model.overtimeBefore)
            model.overtimeBefore = SituationClockingEvent.fromDto(model.overtimeBefore, "TimeEvaluationSituationDefinitionHistory");
        if (originEntity !== "SituationClockingEvent" && model.overtimeEntry)
            model.overtimeEntry = SituationClockingEvent.fromDto(model.overtimeEntry, "TimeEvaluationSituationDefinitionHistory");
        if (originEntity !== "SituationClockingEvent" && model.overtimeDuringMeal)
            model.overtimeDuringMeal = SituationClockingEvent.fromDto(model.overtimeDuringMeal, "TimeEvaluationSituationDefinitionHistory");
        if (originEntity !== "SituationClockingEvent" && model.leaveOvertime)
            model.leaveOvertime = SituationClockingEvent.fromDto(model.leaveOvertime, "TimeEvaluationSituationDefinitionHistory");
        if (originEntity !== "SituationClockingEvent" && model.overtimeAfter)
            model.overtimeAfter = SituationClockingEvent.fromDto(model.overtimeAfter, "TimeEvaluationSituationDefinitionHistory");
        if (originEntity !== "SituationClockingEvent" && model.overtimeDuringRest)
            model.overtimeDuringRest = SituationClockingEvent.fromDto(model.overtimeDuringRest, "TimeEvaluationSituationDefinitionHistory");
        if (originEntity !== "SituationClockingEvent" && model.overtimeOnCompensatedDays)
            model.overtimeOnCompensatedDays = SituationClockingEvent.fromDto(model.overtimeOnCompensatedDays, "TimeEvaluationSituationDefinitionHistory");
        if (originEntity !== "SituationClockingEvent" && model.overtimeDuringHoliday)
            model.overtimeDuringHoliday = SituationClockingEvent.fromDto(model.overtimeDuringHoliday, "TimeEvaluationSituationDefinitionHistory");
        if (originEntity !== "SituationClockingEvent" && model.overtimeDuringDayOff)
            model.overtimeDuringDayOff = SituationClockingEvent.fromDto(model.overtimeDuringDayOff, "TimeEvaluationSituationDefinitionHistory");
        if (originEntity !== "SituationClockingEvent" && model.overtimeSituationOnRelayScheduleHolidays)
            model.overtimeSituationOnRelayScheduleHolidays = SituationClockingEvent.fromDto(model.overtimeSituationOnRelayScheduleHolidays, "TimeEvaluationSituationDefinitionHistory");
        if (originEntity !== "SituationClockingEvent" && model.nightShiftOvertimePremiumSituation)
            model.nightShiftOvertimePremiumSituation = SituationClockingEvent.fromDto(model.nightShiftOvertimePremiumSituation, "TimeEvaluationSituationDefinitionHistory");
        if (originEntity !== "SituationClockingEvent" && model.overtimeSeparationBefore)
            model.overtimeSeparationBefore = SituationClockingEvent.fromDto(model.overtimeSeparationBefore, "TimeEvaluationSituationDefinitionHistory");
        if (originEntity !== "SituationClockingEvent" && model.overtimeSeparationEntry)
            model.overtimeSeparationEntry = SituationClockingEvent.fromDto(model.overtimeSeparationEntry, "TimeEvaluationSituationDefinitionHistory");
        if (originEntity !== "SituationClockingEvent" && model.overtimeSeparationDuringMeal)
            model.overtimeSeparationDuringMeal = SituationClockingEvent.fromDto(model.overtimeSeparationDuringMeal, "TimeEvaluationSituationDefinitionHistory");
        if (originEntity !== "SituationClockingEvent" && model.overtimeSeparationLeave)
            model.overtimeSeparationLeave = SituationClockingEvent.fromDto(model.overtimeSeparationLeave, "TimeEvaluationSituationDefinitionHistory");
        if (originEntity !== "SituationClockingEvent" && model.overtimeSeparationAfter)
            model.overtimeSeparationAfter = SituationClockingEvent.fromDto(model.overtimeSeparationAfter, "TimeEvaluationSituationDefinitionHistory");
        if (originEntity !== "SituationClockingEvent" && model.overtimeSeparationDuringRest)
            model.overtimeSeparationDuringRest = SituationClockingEvent.fromDto(model.overtimeSeparationDuringRest, "TimeEvaluationSituationDefinitionHistory");
        if (originEntity !== "SituationClockingEvent" && model.overtimeSeparationDuringCompensatedDays)
            model.overtimeSeparationDuringCompensatedDays = SituationClockingEvent.fromDto(model.overtimeSeparationDuringCompensatedDays, "TimeEvaluationSituationDefinitionHistory");
        if (originEntity !== "SituationClockingEvent" && model.overtimeSeparationDuringHoliday)
            model.overtimeSeparationDuringHoliday = SituationClockingEvent.fromDto(model.overtimeSeparationDuringHoliday, "TimeEvaluationSituationDefinitionHistory");
        if (originEntity !== "SituationClockingEvent" && model.overtimeSeparationDuringDayOff)
            model.overtimeSeparationDuringDayOff = SituationClockingEvent.fromDto(model.overtimeSeparationDuringDayOff, "TimeEvaluationSituationDefinitionHistory");
        return (/** @type {?} */ (model));
    }
    /**
     * @param {?} timeEvaluationSituationDefinitionHistory
     * @param {?=} originEntity
     * @return {?}
     */
    static toDto(timeEvaluationSituationDefinitionHistory, originEntity) {
        /** @type {?} */
        const dto = Object.assign({}, timeEvaluationSituationDefinitionHistory);
        if (dto.normalOvertimeSeparationLimit && dto.normalOvertimeSeparationLimit !== undefined) {
            dto.normalOvertimeSeparationLimit = convertTimeToMinutes(dto.normalOvertimeSeparationLimit);
        }
        if (dto.overtimeSeparationLimitDuringRest && dto.overtimeSeparationLimitDuringRest !== undefined) {
            dto.overtimeSeparationLimitDuringRest = convertTimeToMinutes(dto.overtimeSeparationLimitDuringRest);
        }
        if (dto.overtimeSeparationLimitDuringCompensatedDays && dto.overtimeSeparationLimitDuringCompensatedDays !== undefined) {
            dto.overtimeSeparationLimitDuringCompensatedDays = convertTimeToMinutes(dto.overtimeSeparationLimitDuringCompensatedDays);
        }
        if (dto.overtimeSeparationLimitDuringHoliday && dto.overtimeSeparationLimitDuringHoliday !== undefined) {
            dto.overtimeSeparationLimitDuringHoliday = convertTimeToMinutes(dto.overtimeSeparationLimitDuringHoliday);
        }
        if (dto.overtimeSeparationLimitDuringDayOff && dto.overtimeSeparationLimitDuringDayOff !== undefined) {
            dto.overtimeSeparationLimitDuringDayOff = convertTimeToMinutes(dto.overtimeSeparationLimitDuringDayOff);
        }
        dto.startDate = dto.startDate && moment$a(dto.startDate).format("YYYY-MM-DD");
        dto.endDate = dto.endDate && moment$a(dto.endDate).format("YYYY-MM-DD");
        dto.createdDate = dto.createdDate && moment$a(dto.createdDate).format();
        dto.lastModifiedDate = dto.lastModifiedDate && moment$a(dto.lastModifiedDate).format();
        delete dto.label;
        if (originEntity !== "TimeEvaluationSituationDefinition" && dto.situationDefinition)
            dto.situationDefinition = TimeEvaluationSituationDefinition.toDto(dto.situationDefinition, "TimeEvaluationSituationDefinitionHistory");
        if (originEntity !== "SituationClockingEvent" && dto.workSituation)
            dto.workSituation = SituationClockingEvent.toDto(dto.workSituation, "TimeEvaluationSituationDefinitionHistory");
        if (originEntity !== "SituationClockingEvent" && dto.nightShiftWorkPremium)
            dto.nightShiftWorkPremium = SituationClockingEvent.toDto(dto.nightShiftWorkPremium, "TimeEvaluationSituationDefinitionHistory");
        if (originEntity !== "SituationClockingEvent" && dto.invalidEventsSituation)
            dto.invalidEventsSituation = SituationClockingEvent.toDto(dto.invalidEventsSituation, "TimeEvaluationSituationDefinitionHistory");
        if (originEntity !== "SituationClockingEvent" && dto.vacationPaidLeaveSituation)
            dto.vacationPaidLeaveSituation = SituationClockingEvent.toDto(dto.vacationPaidLeaveSituation, "TimeEvaluationSituationDefinitionHistory");
        if (originEntity !== "SituationClockingEvent" && dto.dailyRestViolationSituation)
            dto.dailyRestViolationSituation = SituationClockingEvent.toDto(dto.dailyRestViolationSituation, "TimeEvaluationSituationDefinitionHistory");
        if (originEntity !== "SituationClockingEvent" && dto.workBreakViolationSituation)
            dto.workBreakViolationSituation = SituationClockingEvent.toDto(dto.workBreakViolationSituation, "TimeEvaluationSituationDefinitionHistory");
        if (originEntity !== "SituationClockingEvent" && dto.absenceSituation)
            dto.absenceSituation = SituationClockingEvent.toDto(dto.absenceSituation, "TimeEvaluationSituationDefinitionHistory");
        if (originEntity !== "SituationClockingEvent" && dto.tardinessSituation)
            dto.tardinessSituation = SituationClockingEvent.toDto(dto.tardinessSituation, "TimeEvaluationSituationDefinitionHistory");
        if (originEntity !== "SituationClockingEvent" && dto.intermediateLeaveSituation)
            dto.intermediateLeaveSituation = SituationClockingEvent.toDto(dto.intermediateLeaveSituation, "TimeEvaluationSituationDefinitionHistory");
        if (originEntity !== "SituationClockingEvent" && dto.earlyLeaveSituation)
            dto.earlyLeaveSituation = SituationClockingEvent.toDto(dto.earlyLeaveSituation, "TimeEvaluationSituationDefinitionHistory");
        if (originEntity !== "SituationClockingEvent" && dto.absenceSituationOnRelayScheduleHolidays)
            dto.absenceSituationOnRelayScheduleHolidays = SituationClockingEvent.toDto(dto.absenceSituationOnRelayScheduleHolidays, "TimeEvaluationSituationDefinitionHistory");
        if (originEntity !== "SituationClockingEvent" && dto.unauthorizedOvertime)
            dto.unauthorizedOvertime = SituationClockingEvent.toDto(dto.unauthorizedOvertime, "TimeEvaluationSituationDefinitionHistory");
        if (originEntity !== "SituationClockingEvent" && dto.overtimeBefore)
            dto.overtimeBefore = SituationClockingEvent.toDto(dto.overtimeBefore, "TimeEvaluationSituationDefinitionHistory");
        if (originEntity !== "SituationClockingEvent" && dto.overtimeEntry)
            dto.overtimeEntry = SituationClockingEvent.toDto(dto.overtimeEntry, "TimeEvaluationSituationDefinitionHistory");
        if (originEntity !== "SituationClockingEvent" && dto.overtimeDuringMeal)
            dto.overtimeDuringMeal = SituationClockingEvent.toDto(dto.overtimeDuringMeal, "TimeEvaluationSituationDefinitionHistory");
        if (originEntity !== "SituationClockingEvent" && dto.leaveOvertime)
            dto.leaveOvertime = SituationClockingEvent.toDto(dto.leaveOvertime, "TimeEvaluationSituationDefinitionHistory");
        if (originEntity !== "SituationClockingEvent" && dto.overtimeAfter)
            dto.overtimeAfter = SituationClockingEvent.toDto(dto.overtimeAfter, "TimeEvaluationSituationDefinitionHistory");
        if (originEntity !== "SituationClockingEvent" && dto.overtimeDuringRest)
            dto.overtimeDuringRest = SituationClockingEvent.toDto(dto.overtimeDuringRest, "TimeEvaluationSituationDefinitionHistory");
        if (originEntity !== "SituationClockingEvent" && dto.overtimeOnCompensatedDays)
            dto.overtimeOnCompensatedDays = SituationClockingEvent.toDto(dto.overtimeOnCompensatedDays, "TimeEvaluationSituationDefinitionHistory");
        if (originEntity !== "SituationClockingEvent" && dto.overtimeDuringHoliday)
            dto.overtimeDuringHoliday = SituationClockingEvent.toDto(dto.overtimeDuringHoliday, "TimeEvaluationSituationDefinitionHistory");
        if (originEntity !== "SituationClockingEvent" && dto.overtimeDuringDayOff)
            dto.overtimeDuringDayOff = SituationClockingEvent.toDto(dto.overtimeDuringDayOff, "TimeEvaluationSituationDefinitionHistory");
        if (originEntity !== "SituationClockingEvent" && dto.overtimeSituationOnRelayScheduleHolidays)
            dto.overtimeSituationOnRelayScheduleHolidays = SituationClockingEvent.toDto(dto.overtimeSituationOnRelayScheduleHolidays, "TimeEvaluationSituationDefinitionHistory");
        if (originEntity !== "SituationClockingEvent" && dto.nightShiftOvertimePremiumSituation)
            dto.nightShiftOvertimePremiumSituation = SituationClockingEvent.toDto(dto.nightShiftOvertimePremiumSituation, "TimeEvaluationSituationDefinitionHistory");
        if (originEntity !== "SituationClockingEvent" && dto.overtimeSeparationBefore)
            dto.overtimeSeparationBefore = SituationClockingEvent.toDto(dto.overtimeSeparationBefore, "TimeEvaluationSituationDefinitionHistory");
        if (originEntity !== "SituationClockingEvent" && dto.overtimeSeparationEntry)
            dto.overtimeSeparationEntry = SituationClockingEvent.toDto(dto.overtimeSeparationEntry, "TimeEvaluationSituationDefinitionHistory");
        if (originEntity !== "SituationClockingEvent" && dto.overtimeSeparationDuringMeal)
            dto.overtimeSeparationDuringMeal = SituationClockingEvent.toDto(dto.overtimeSeparationDuringMeal, "TimeEvaluationSituationDefinitionHistory");
        if (originEntity !== "SituationClockingEvent" && dto.overtimeSeparationLeave)
            dto.overtimeSeparationLeave = SituationClockingEvent.toDto(dto.overtimeSeparationLeave, "TimeEvaluationSituationDefinitionHistory");
        if (originEntity !== "SituationClockingEvent" && dto.overtimeSeparationAfter)
            dto.overtimeSeparationAfter = SituationClockingEvent.toDto(dto.overtimeSeparationAfter, "TimeEvaluationSituationDefinitionHistory");
        if (originEntity !== "SituationClockingEvent" && dto.overtimeSeparationDuringRest)
            dto.overtimeSeparationDuringRest = SituationClockingEvent.toDto(dto.overtimeSeparationDuringRest, "TimeEvaluationSituationDefinitionHistory");
        if (originEntity !== "SituationClockingEvent" && dto.overtimeSeparationDuringCompensatedDays)
            dto.overtimeSeparationDuringCompensatedDays = SituationClockingEvent.toDto(dto.overtimeSeparationDuringCompensatedDays, "TimeEvaluationSituationDefinitionHistory");
        if (originEntity !== "SituationClockingEvent" && dto.overtimeSeparationDuringHoliday)
            dto.overtimeSeparationDuringHoliday = SituationClockingEvent.toDto(dto.overtimeSeparationDuringHoliday, "TimeEvaluationSituationDefinitionHistory");
        if (originEntity !== "SituationClockingEvent" && dto.overtimeSeparationDuringDayOff)
            dto.overtimeSeparationDuringDayOff = SituationClockingEvent.toDto(dto.overtimeSeparationDuringDayOff, "TimeEvaluationSituationDefinitionHistory");
        return dto;
    }
}
if (false) {
    /** @type {?} */
    TimeEvaluationSituationDefinitionHistory.prototype.id;
    /** @type {?} */
    TimeEvaluationSituationDefinitionHistory.prototype.situationDefinition;
    /** @type {?} */
    TimeEvaluationSituationDefinitionHistory.prototype.startDate;
    /** @type {?} */
    TimeEvaluationSituationDefinitionHistory.prototype.endDate;
    /** @type {?} */
    TimeEvaluationSituationDefinitionHistory.prototype.workSituation;
    /** @type {?} */
    TimeEvaluationSituationDefinitionHistory.prototype.nightShiftWorkPremium;
    /** @type {?} */
    TimeEvaluationSituationDefinitionHistory.prototype.invalidEventsSituation;
    /** @type {?} */
    TimeEvaluationSituationDefinitionHistory.prototype.vacationPaidLeaveSituation;
    /** @type {?} */
    TimeEvaluationSituationDefinitionHistory.prototype.dailyRestViolationSituation;
    /** @type {?} */
    TimeEvaluationSituationDefinitionHistory.prototype.workBreakViolationSituation;
    /** @type {?} */
    TimeEvaluationSituationDefinitionHistory.prototype.absenceSituation;
    /** @type {?} */
    TimeEvaluationSituationDefinitionHistory.prototype.tardinessSituation;
    /** @type {?} */
    TimeEvaluationSituationDefinitionHistory.prototype.intermediateLeaveSituation;
    /** @type {?} */
    TimeEvaluationSituationDefinitionHistory.prototype.earlyLeaveSituation;
    /** @type {?} */
    TimeEvaluationSituationDefinitionHistory.prototype.absenceSituationOnRelayScheduleHolidays;
    /** @type {?} */
    TimeEvaluationSituationDefinitionHistory.prototype.percentageNextDay;
    /** @type {?} */
    TimeEvaluationSituationDefinitionHistory.prototype.normalOvertimeSeparationLimit;
    /** @type {?} */
    TimeEvaluationSituationDefinitionHistory.prototype.separateOvertimeAfterConvertingNightShiftHours;
    /** @type {?} */
    TimeEvaluationSituationDefinitionHistory.prototype.unauthorizedOvertime;
    /** @type {?} */
    TimeEvaluationSituationDefinitionHistory.prototype.overtimeBefore;
    /** @type {?} */
    TimeEvaluationSituationDefinitionHistory.prototype.overtimeEntry;
    /** @type {?} */
    TimeEvaluationSituationDefinitionHistory.prototype.overtimeDuringMeal;
    /** @type {?} */
    TimeEvaluationSituationDefinitionHistory.prototype.leaveOvertime;
    /** @type {?} */
    TimeEvaluationSituationDefinitionHistory.prototype.overtimeAfter;
    /** @type {?} */
    TimeEvaluationSituationDefinitionHistory.prototype.overtimeSeparationLimitDuringRest;
    /** @type {?} */
    TimeEvaluationSituationDefinitionHistory.prototype.overtimeDuringRest;
    /** @type {?} */
    TimeEvaluationSituationDefinitionHistory.prototype.overtimeSeparationLimitDuringCompensatedDays;
    /** @type {?} */
    TimeEvaluationSituationDefinitionHistory.prototype.overtimeOnCompensatedDays;
    /** @type {?} */
    TimeEvaluationSituationDefinitionHistory.prototype.overtimeSeparationLimitDuringHoliday;
    /** @type {?} */
    TimeEvaluationSituationDefinitionHistory.prototype.overtimeDuringHoliday;
    /** @type {?} */
    TimeEvaluationSituationDefinitionHistory.prototype.overtimeSeparationLimitDuringDayOff;
    /** @type {?} */
    TimeEvaluationSituationDefinitionHistory.prototype.overtimeDuringDayOff;
    /** @type {?} */
    TimeEvaluationSituationDefinitionHistory.prototype.overtimeSituationOnRelayScheduleHolidays;
    /** @type {?} */
    TimeEvaluationSituationDefinitionHistory.prototype.nightShiftOvertimePremiumSituation;
    /** @type {?} */
    TimeEvaluationSituationDefinitionHistory.prototype.overtimeSeparationBefore;
    /** @type {?} */
    TimeEvaluationSituationDefinitionHistory.prototype.overtimeSeparationEntry;
    /** @type {?} */
    TimeEvaluationSituationDefinitionHistory.prototype.overtimeSeparationDuringMeal;
    /** @type {?} */
    TimeEvaluationSituationDefinitionHistory.prototype.overtimeSeparationLeave;
    /** @type {?} */
    TimeEvaluationSituationDefinitionHistory.prototype.overtimeSeparationAfter;
    /** @type {?} */
    TimeEvaluationSituationDefinitionHistory.prototype.overtimeSeparationDuringRest;
    /** @type {?} */
    TimeEvaluationSituationDefinitionHistory.prototype.overtimeSeparationDuringCompensatedDays;
    /** @type {?} */
    TimeEvaluationSituationDefinitionHistory.prototype.overtimeSeparationDuringHoliday;
    /** @type {?} */
    TimeEvaluationSituationDefinitionHistory.prototype.overtimeSeparationDuringDayOff;
    /** @type {?} */
    TimeEvaluationSituationDefinitionHistory.prototype.createdBy;
    /** @type {?} */
    TimeEvaluationSituationDefinitionHistory.prototype.createdDate;
    /** @type {?} */
    TimeEvaluationSituationDefinitionHistory.prototype.lastModifiedBy;
    /** @type {?} */
    TimeEvaluationSituationDefinitionHistory.prototype.lastModifiedDate;
    /** @type {?} */
    TimeEvaluationSituationDefinitionHistory.prototype.custom;
}

/**
 * @fileoverview added by tsickle
 * Generated from: core/entities/time-evaluation-situation-definition-history/time-evaluation-situation-definition-history-dto.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/*{CA:PACKAGE_IMPORTS:START}*/
/*{CA:PACKAGE_IMPORTS:END}*/
/*{CA:PROJECT_IMPORTS:START}*/
/*{CA:PROJECT_IMPORTS:END}*/
/**
 * @record
 */
function TimeEvaluationSituationDefinitionHistoryDto() { }
if (false) {
    /** @type {?|undefined} */
    TimeEvaluationSituationDefinitionHistoryDto.prototype.id;
    /** @type {?} */
    TimeEvaluationSituationDefinitionHistoryDto.prototype.situationDefinition;
    /** @type {?} */
    TimeEvaluationSituationDefinitionHistoryDto.prototype.startDate;
    /** @type {?|undefined} */
    TimeEvaluationSituationDefinitionHistoryDto.prototype.endDate;
    /** @type {?|undefined} */
    TimeEvaluationSituationDefinitionHistoryDto.prototype.workSituation;
    /** @type {?|undefined} */
    TimeEvaluationSituationDefinitionHistoryDto.prototype.nightShiftWorkPremium;
    /** @type {?|undefined} */
    TimeEvaluationSituationDefinitionHistoryDto.prototype.invalidEventsSituation;
    /** @type {?|undefined} */
    TimeEvaluationSituationDefinitionHistoryDto.prototype.vacationPaidLeaveSituation;
    /** @type {?|undefined} */
    TimeEvaluationSituationDefinitionHistoryDto.prototype.dailyRestViolationSituation;
    /** @type {?|undefined} */
    TimeEvaluationSituationDefinitionHistoryDto.prototype.workBreakViolationSituation;
    /** @type {?|undefined} */
    TimeEvaluationSituationDefinitionHistoryDto.prototype.absenceSituation;
    /** @type {?|undefined} */
    TimeEvaluationSituationDefinitionHistoryDto.prototype.tardinessSituation;
    /** @type {?|undefined} */
    TimeEvaluationSituationDefinitionHistoryDto.prototype.intermediateLeaveSituation;
    /** @type {?|undefined} */
    TimeEvaluationSituationDefinitionHistoryDto.prototype.earlyLeaveSituation;
    /** @type {?|undefined} */
    TimeEvaluationSituationDefinitionHistoryDto.prototype.absenceSituationOnRelayScheduleHolidays;
    /** @type {?|undefined} */
    TimeEvaluationSituationDefinitionHistoryDto.prototype.percentageNextDay;
    /** @type {?|undefined} */
    TimeEvaluationSituationDefinitionHistoryDto.prototype.normalOvertimeSeparationLimit;
    /** @type {?|undefined} */
    TimeEvaluationSituationDefinitionHistoryDto.prototype.separateOvertimeAfterConvertingNightShiftHours;
    /** @type {?|undefined} */
    TimeEvaluationSituationDefinitionHistoryDto.prototype.unauthorizedOvertime;
    /** @type {?|undefined} */
    TimeEvaluationSituationDefinitionHistoryDto.prototype.overtimeBefore;
    /** @type {?|undefined} */
    TimeEvaluationSituationDefinitionHistoryDto.prototype.overtimeEntry;
    /** @type {?|undefined} */
    TimeEvaluationSituationDefinitionHistoryDto.prototype.overtimeDuringMeal;
    /** @type {?|undefined} */
    TimeEvaluationSituationDefinitionHistoryDto.prototype.leaveOvertime;
    /** @type {?|undefined} */
    TimeEvaluationSituationDefinitionHistoryDto.prototype.overtimeAfter;
    /** @type {?|undefined} */
    TimeEvaluationSituationDefinitionHistoryDto.prototype.overtimeSeparationLimitDuringRest;
    /** @type {?|undefined} */
    TimeEvaluationSituationDefinitionHistoryDto.prototype.overtimeDuringRest;
    /** @type {?|undefined} */
    TimeEvaluationSituationDefinitionHistoryDto.prototype.overtimeSeparationLimitDuringCompensatedDays;
    /** @type {?|undefined} */
    TimeEvaluationSituationDefinitionHistoryDto.prototype.overtimeOnCompensatedDays;
    /** @type {?|undefined} */
    TimeEvaluationSituationDefinitionHistoryDto.prototype.overtimeSeparationLimitDuringHoliday;
    /** @type {?|undefined} */
    TimeEvaluationSituationDefinitionHistoryDto.prototype.overtimeDuringHoliday;
    /** @type {?|undefined} */
    TimeEvaluationSituationDefinitionHistoryDto.prototype.overtimeSeparationLimitDuringDayOff;
    /** @type {?|undefined} */
    TimeEvaluationSituationDefinitionHistoryDto.prototype.overtimeDuringDayOff;
    /** @type {?|undefined} */
    TimeEvaluationSituationDefinitionHistoryDto.prototype.overtimeSituationOnRelayScheduleHolidays;
    /** @type {?|undefined} */
    TimeEvaluationSituationDefinitionHistoryDto.prototype.nightShiftOvertimePremiumSituation;
    /** @type {?|undefined} */
    TimeEvaluationSituationDefinitionHistoryDto.prototype.overtimeSeparationBefore;
    /** @type {?|undefined} */
    TimeEvaluationSituationDefinitionHistoryDto.prototype.overtimeSeparationEntry;
    /** @type {?|undefined} */
    TimeEvaluationSituationDefinitionHistoryDto.prototype.overtimeSeparationDuringMeal;
    /** @type {?|undefined} */
    TimeEvaluationSituationDefinitionHistoryDto.prototype.overtimeSeparationLeave;
    /** @type {?|undefined} */
    TimeEvaluationSituationDefinitionHistoryDto.prototype.overtimeSeparationAfter;
    /** @type {?|undefined} */
    TimeEvaluationSituationDefinitionHistoryDto.prototype.overtimeSeparationDuringRest;
    /** @type {?|undefined} */
    TimeEvaluationSituationDefinitionHistoryDto.prototype.overtimeSeparationDuringCompensatedDays;
    /** @type {?|undefined} */
    TimeEvaluationSituationDefinitionHistoryDto.prototype.overtimeSeparationDuringHoliday;
    /** @type {?|undefined} */
    TimeEvaluationSituationDefinitionHistoryDto.prototype.overtimeSeparationDuringDayOff;
    /** @type {?|undefined} */
    TimeEvaluationSituationDefinitionHistoryDto.prototype.createdBy;
    /** @type {?|undefined} */
    TimeEvaluationSituationDefinitionHistoryDto.prototype.createdDate;
    /** @type {?|undefined} */
    TimeEvaluationSituationDefinitionHistoryDto.prototype.lastModifiedBy;
    /** @type {?|undefined} */
    TimeEvaluationSituationDefinitionHistoryDto.prototype.lastModifiedDate;
    /** @type {?|undefined} */
    TimeEvaluationSituationDefinitionHistoryDto.prototype.custom;
}

/**
 * @fileoverview added by tsickle
 * Generated from: core/entities/time-evaluation-situation-definition-history/index.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

/**
 * @fileoverview added by tsickle
 * Generated from: core/entities/situation-clocking-event/situation-clocking-event-dto.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/*{CA:PACKAGE_IMPORTS:START}*/
/*{CA:PACKAGE_IMPORTS:END}*/
/*{CA:PROJECT_IMPORTS:START}*/
/*{CA:PROJECT_IMPORTS:END}*/
/**
 * @record
 */
function SituationClockingEventDto() { }
if (false) {
    /** @type {?|undefined} */
    SituationClockingEventDto.prototype.id;
    /** @type {?|undefined} */
    SituationClockingEventDto.prototype.situation;
    /** @type {?|undefined} */
    SituationClockingEventDto.prototype.complementarySituation;
    /** @type {?|undefined} */
    SituationClockingEventDto.prototype.exceptionSituation;
    /** @type {?|undefined} */
    SituationClockingEventDto.prototype.mandatoryAdjustmentReason;
    /** @type {?} */
    SituationClockingEventDto.prototype.daytimeSituation;
    /** @type {?|undefined} */
    SituationClockingEventDto.prototype.convertNightHours;
    /** @type {?|undefined} */
    SituationClockingEventDto.prototype.obligateAttachmentOnLeave;
    /** @type {?|undefined} */
    SituationClockingEventDto.prototype.createdBy;
    /** @type {?|undefined} */
    SituationClockingEventDto.prototype.createdDate;
    /** @type {?|undefined} */
    SituationClockingEventDto.prototype.lastModifiedBy;
    /** @type {?|undefined} */
    SituationClockingEventDto.prototype.lastModifiedDate;
    /** @type {?|undefined} */
    SituationClockingEventDto.prototype.custom;
}

/**
 * @fileoverview added by tsickle
 * Generated from: core/entities/situation-clocking-event/index.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

/**
 * @fileoverview added by tsickle
 * Generated from: core/enums/clocking-event-tolerance-type.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/** @enum {string} */
const ClockingEventToleranceType = {
    V1: "V1",
    V2: "V2",
};

/**
 * @fileoverview added by tsickle
 * Generated from: core/enums/consider-clocking-event-interval-type.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/** @enum {string} */
const ConsiderClockingEventIntervalType = {
    V1: "V1",
    V2: "V2",
    V3: "V3",
    V4: "V4",
};

/**
 * @fileoverview added by tsickle
 * Generated from: core/enums/retroactive-adjustment-type.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/** @enum {string} */
const RetroactiveAdjustmentType = {
    V1: "V1",
    V2: "V2",
};

/**
 * @fileoverview added by tsickle
 * Generated from: core/enums/verified-days-control-type.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/** @enum {string} */
const VerifiedDaysControlType = {
    V0: "V0",
    V1: "V1",
    V2: "V2",
};

/**
 * @fileoverview added by tsickle
 * Generated from: core/enums/index.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

/**
 * @fileoverview added by tsickle
 * Generated from: core/index.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

/**
 * @fileoverview added by tsickle
 * Generated from: public-api.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

/**
 * @fileoverview added by tsickle
 * Generated from: senior-gestao-pessoas-hcm-clocking-event-foundation-schedules-histories.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

export { Bridge, BridgeFormComponent, BridgeFormModule, BridgeService, ClockingEventToleranceType, CompanyClockingEventIndications, CompanyClockingEventIndicationsService, ConsiderClockingEventIntervalType, CoreSchedulesHistoriesModule, E001Pes, E001PesService, Employee, EmployeeService, FieldCustomizationService, FiltersStorageService, FocusService, PaginatorStorageService, RetroactiveAdjustmentType, Situation, SituationClockingEvent, SituationClockingEventService, SituationService, StorageService, TimeEvaluationDefinition, TimeEvaluationDefinitionService, TimeEvaluationSituationDefinition, TimeEvaluationSituationDefinitionHistory, TimeEvaluationSituationDefinitionHistoryService, TimeEvaluationSituationDefinitionService, VerifiedDaysControlType, convertMinutesToTime, convertTimeToMinutes, getTypeInformation, isValidFilter, mergeUnique, SharedScheduleModule as ɵa, BridgeModule as ɵb, EntityService as ɵc, EmployeeModule as ɵd, E001PesModule as ɵe, CompanyClockingEventIndicationsModule as ɵf, TimeEvaluationDefinitionModule as ɵg, SituationModule as ɵh, TimeEvaluationSituationDefinitionModule as ɵi, TimeEvaluationSituationDefinitionHistoryModule as ɵj, SituationClockingEventModule as ɵk };
//# sourceMappingURL=senior-gestao-pessoas-hcm-clocking-event-foundation-schedules-histories.js.map
